OC.L10N.register(
    "spreed",
    {
    "a conversation" : "en konversation",
    "(Duration %s)" : "(Varaktighet%s)",
    "You attended a call with {user1}" : "Du deltog i ett samtal med {user1}",
    "_%n guest_::_%n guests_" : ["%n gäst","%n gäster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i ett samtal med {user1} och {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i ett samtal med {user1}, {user2} och {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i ett samtal med {user1}, {user2}, {user3} och {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i ett samtal med {user1}, {user2}, {user3}, {user4} och {user5}",
    "_%n other_::_%n others_" : ["%n annan","%n andra"],
    "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du blev inbjuden till en <strong>konversation</strong> eller hade ett <strong>samtal</strong>",
    "Other activities" : "Andra aktiviteter",
    "Talk" : "Talk",
    "Guest" : "Gäst",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Välkommen till Nextcloud Talk!\nI den här konversationen kommer du att informeras om nya funktioner som är tillgängliga i Nextcloud Talk.",
    "## New in Talk %s" : "## Nytt i Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-till-en diskussioner är nu permanent och kan inte längre ändras till gruppkonversationer av misstag. Dessutom när en av deltagarna lämnar diskussionen tas diskussionen inte längra automatiskt bort. Enbart om bägge deltagare lämnar kommer diskussionen att tas bort från servern.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
    "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
    "- With projects you can create quick links between conversations, files and other items" : "- Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
    "- You can now mention guests in the chat" : "- Du kan nu nämna gäster i chatten",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svara direkt på meddelanden som ger de andra användarna mer sammanhang vad ditt meddelande handlar om",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Sökning efter konversationer och deltagare kommer nu också att filtrera dina befintliga konversationer, vilket gör det mycket lättare att hitta tidigare konversationer",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu lägga till anpassade användargrupper i konversationer när cirkelappen är installerad",
    "- Check out the new grid and call view" : "- Kolla in det nya gränssnittet och samtals-vyn",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Nu går det att ladda upp filer direkt med drag'n'drop från din enhet  till chatten",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Delade filer visas nu direkt inuti chatten och öppnas med rätt applikation.",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Nu kan du söka efter chattar och meddelanden gemensamt från sökrutan i menyn",
    "- Spice up your messages with emojis from the emoji picker" : "- Snygga till dina meddelanden med emojier",
    "- You can now change your camera and microphone while being in a call" : "- Nu går det att ändra kameran och mikrofonen medans du sitter i ett samtal",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Förtydliga syftet med din diskussion med en beskrivning vilket underlättar för inloggade användare att på egen hand hitta och ansluta till den",
    "- See a read status and send failed messages again" : "- Visa lässtatus och sänd felmeddelanden på nytt",
    "- Raise your hand in a call with the R key" : "- Räck upp handen i ett samtal med R-tangenten",
    "- Join the same conversation and call from multiple devices" : "- Anslut till samma diskussion och ring från flera enheter",
    "- Send voice messages, share your location or contact details" : "- Skicka röstmeddelanden, dela din plats eller kontaktinformation",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Lägg till grupper till en diskussion och nya gruppmedlemmar kommer automatiskt att läggas till som deltagare",
    "- A preview of your audio and video is shown before joining a call" : "- En förhandsgranskning av ditt ljud och video visas innan anslutning till ett samtal",
    "- You can now blur your background in the newly designed call view" : "- Nu kan du sudda ut bakgrunden i den nyligen skapade samtalsvyn",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatorer kan nu tilldela allmänna och individuella behörigheter till deltagare",
    "- You can now react to chat messages" : "- Du kan nu reagera på chattmeddelande",
    "- In the sidebar you can now find an overview of the latest shared items" : "- I marginallisten kan du nu hitta en översikt över de senast delade objekten",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Använd en opinionsundersökning för att samla in åsikter från andra eller bestämma ett datum",
    "- Configure an expiration time for chat messages" : "- Konfigurera en utgångstid för chattmeddelanden",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Starta samtal utan att notifiera andra deltagare i stora konversationer. Du kan skicka individuella samtalsnotifieringar så fort samtalet har avslutats.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Skicka chattmeddelanden utan att notifiera mottagaren förutsatt att det inte är brådskande",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojier kan nu autokompletteras om man skriver \".\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Länka olika objekt med nya smart-picker genom att skriva ett \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatorer kan nu skapa grupprum (kräver High-performance backend)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Samtal kan nu spelas in (kräver High-performance backend)",
    "- Conversations can now have an avatar or emoji as icon" : "- Konversationer kan nu ha en avatar eller en emoji som ikon",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Utöver suddig bakgrund finns nu även virtuella bakgrunder tillgängligt i videosamtal",
    "- Reactions are now available during calls" : "- Reaktioner finns nu tillgängligt under samtal",
    "- Typing indicators show which users are currently typing a message" : "- Skrivningsindikationer visar vilken användare som i realtid skriver ett meddelande",
    "- Groups can now be mentioned in chats" : "- Grupper kan nu nämnas i chattar",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Samtalsinspelningar transkiberas automatiskt om en transkiberingsproviderapp är registrerad",
    "- Chat messages can be translated if a translation provider app is registered" : "Chattmeddelanden kan översättas om en översättningsproviderapp är registrerad",
    "- **Markdown** can now be used in _chat_ messages" : "-  **Markdown** kan nu användas i _chat_ meddelanden",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks finns nu tillgängligt för att implementera bots. Läs dokumentationen för mer information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Ställ in en påminnelse på ett chattmeddelande för att senare bli notifierad",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Använd **Egna anteckningar** för att göra anteckningar och dela information mellan dina enheter",
    "- Captions allow to send a message with a file at the same time" : "- Bildtexter tillåter att skicka ett meddelande med en fil samtidigt",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video av talare är nu synlig när skärmen delas och samtalsreaktioner är animerade",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Meddelanden kan nu redigeras av inloggade författare och moderatorer i 6 timmar",
    "- Unsent message drafts are now saved in your browser" : "- Ej skickade meddelandeutkast sparas nu i din webbläsare",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Textchatt kan nu göras på ett federerat sätt med andra Talk-servrar",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatorer kan nu blockera konton och gäster för att förhindra att de återansluter till en konversation",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Kommande samtal från länkade kalenderhändelser och frånvarande ersättningar visas nu i konversationer",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Samtal kan nu göras på ett federerat sätt med andra Talk-servrar (kräver High-performance backend)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Introducerar Nextcloud Talk skrivbordsklient för Windows, macOS och Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Sammanfatta samtalsinspelningar och olästa meddelanden i chattar med Nextcloud Assistant",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Förbättrade möten med att känna igen gäster som bjudits in via deras e-postadress, import av deltagarlistor, utkast till omröstningar och nedladdning av deltagarlistor för samtal",
    "- Archive conversations to stay focused" : "- Arkivera konversationer för att hålla fokus",
    "- Schedule a meeting into your calendar from within a conversation" : "- Schemalägg ett möte i din kalender direkt från en konversation",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Sök efter meddelanden från den aktuella konversationen direkt i den högra sidopanelen",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Se fler konversationer direkt med den nya kompakta listan (aktivera i Talk-inställningarna)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Möteskonversationer synkar nu titel och beskrivning från kalendern och döljs med ett sökfilter tills de närmar sig starttidpunkten",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Markera konversationer som känsliga i aviseringsinställningarna för att dölja meddelandeinnehåll i konversationslistan och aviseringar",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- För att få pushaviseringar under “Stör ej”, markera konversationer som viktiga",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Lägg till fler deltagare i ett en-till-en-samtal för att skapa ett nytt gruppsamtal direkt",
    "- Use threads to keep your chat and discussions organized" : "- Använd trådar för att hålla din chatt och dina diskussioner organiserade",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Live-transkriberingar är nu tillgängliga under samtalet (kräver live-transcription ExApp och High-performance backend)",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderatorer kan nu fästa meddelanden så att de hålls kvar överst",
    "- Schedule a message to send it at a later time" : "- Schemalägg ett meddelande för att skicka det senare",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "- Konversationstaggar, gruppering och sortering för att organisera konversationslistan",
    "- Voice-rooms to connect spontaneously" : "- Röstrum för spontana anslutningar",
    "- Presets for quick conversation configuration during creation" : "- Förinställningar för snabb samtalskonfiguration vid skapande",
    "- Direct calls from profile menus for calls within other apps" : "- Direktsamtal från profilmenyer för samtal inom andra appar",
    "_All %n participant_::_All %n participants_" : ["Alla %n deltagare","Alla %n deltagare"],
    "Talk updates ✅" : "Talk-uppdateringar ✅",
    "Reaction deleted by author" : "Svar har tagits bort av författaren",
    "{actor} created the conversation" : "{actor} skapade konversationen",
    "You created the conversation" : "Du skapade konversationen",
    "System created the conversation" : "Systemet skapade konversationen",
    "An administrator created the conversation" : "En administratör skapade konversationen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administratör döpte om konversationen från \"%1$s\" till \"%2$s\"",
    "{actor} set the description" : "{actor} anger beskrivning",
    "You set the description" : "Du anger beskrivningen",
    "An administrator set the description" : "En administratör anger beskrivningen",
    "{actor} removed the description" : "{actor} tog bort beskrivningen",
    "You removed the description" : "Du tog bort beskrivningen",
    "An administrator removed the description" : "En administratör tog bort beskrivningen",
    "You started a silent call" : "Du startade ett tyst samtal",
    "Outgoing silent call" : "Utgående tyst samtal",
    "{actor} started a silent call" : "{actor} startade ett tyst samtal",
    "Incoming silent call" : "Inkommande tyst samtal",
    "You started a call" : "Du startade ett samtal",
    "Outgoing call" : "Utgående samtal",
    "{actor} started a call" : "{actor} startade ett samtal",
    "Incoming call" : "Inkommande samtal",
    "{actor} joined the call" : "{actor} gick med i samtalet",
    "You joined the call" : "Du gick med i samtalet",
    "{actor} left the call" : "{actor} lämnade samtalet",
    "You left the call" : "Du lämnade samtalet",
    "{actor} unlocked the conversation" : "{actor} låste upp konversationen",
    "You unlocked the conversation" : "Du låste upp konversationen",
    "An administrator unlocked the conversation" : "En administratör låste upp konversationen",
    "{actor} locked the conversation" : "{actor} låste konversationen",
    "You locked the conversation" : "Du låste konversationen",
    "An administrator locked the conversation" : "En administratör låste konversationen",
    "{actor} limited the conversation to the current participants" : "{actor} begränsade konversationen för nuvarande deltagare",
    "You limited the conversation to the current participants" : "Du begränsade diskussionen till närvarande deltagare",
    "An administrator limited the conversation to the current participants" : "En administratör begränsade diskussionen till närvarande deltagare",
    "{actor} opened the conversation to registered users" : "{actor} öppnade konversationen för registrerade användare",
    "You opened the conversation to registered users" : "Du öppnade konversationen för registrerade användare",
    "An administrator opened the conversation to registered users" : "En administratör öppnade konversationen för registrerade användare",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} öppnade konversationen för registrerade användare och användare som skapats med appen Gäster",
    "You opened the conversation to registered users and users created with the Guests app" : "Du öppnade konversationen för registrerade användare och användare som skapats med appen Gäster",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "En administratör öppnade konversationen för registrerade användare och användare som skapats med appen Gäster",
    "The conversation is now open to everyone" : "Konversationen är nu öppen för alla",
    "{actor} opened the conversation to everyone" : "{actor} öppnade konversationen för alla",
    "You opened the conversation to everyone" : "Du öppnade konversationen för alla",
    "{actor} restricted the conversation to moderators" : "{actor} begränsade konversationen till moderatorer",
    "You restricted the conversation to moderators" : "Du begränsade konversationen till moderatorer",
    "{actor} started breakout rooms" : "{actor} startade grupprum",
    "You started breakout rooms" : "Du startade grupprum",
    "{actor} stopped breakout rooms" : "{actor} stoppade grupprum",
    "You stopped breakout rooms" : "Du stoppade grupprum",
    "{actor} allowed guests" : "{actor} tillåter gäster",
    "You allowed guests" : "Du tillåter gäster",
    "An administrator allowed guests" : "En administratör har tillåtit gäster",
    "{actor} disallowed guests" : "{actor} tillåter inte gäster",
    "You disallowed guests" : "Du tillåter inte gäster",
    "An administrator disallowed guests" : "En administratör tillåter inte gäster",
    "{actor} set a password" : "{actor} satte ett lösenord",
    "You set a password" : "Du satte ett lösenord",
    "An administrator set a password" : "En administratör har aktiverat ett lösenord",
    "{actor} removed the password" : "{actor} tog bort lösenordet",
    "You removed the password" : "Du tog bort lösenordet",
    "An administrator removed the password" : "En administratör har tagit bort lösenordet",
    "{actor} added {user}" : "{actor} la till {user}",
    "You joined the conversation" : "Du gick med i konversationen",
    "{actor} joined the conversation" : "{actor} gick med i konversationen",
    "You added {user}" : "Du lade till {user}",
    "{actor} added you" : "{actor} lade till dig",
    "An administrator added you" : "En administratör lade till dig",
    "An administrator added {user}" : "En administratör lade till {user}",
    "You left the conversation" : "Du lämnade konversationen",
    "{actor} left the conversation" : "{actor} lämnade konversationen",
    "{actor} removed {user}" : "{actor} tog bort {user}",
    "You removed {user}" : "Du tog bort {user}",
    "{actor} removed you" : "{actor} tog bort dig",
    "An administrator removed you" : "En administratör tog bort dig",
    "An administrator removed {user}" : "En administratör tog bort {user}",
    "{actor} invited {federated_user}" : "{actor} bjöd in {federated_user}",
    "You invited {federated_user}" : "Du bjöd in {federated_user}",
    "You accepted the invitation" : "Du accepterade inbjudan",
    "{actor} invited you" : "{actor} bjöd in dig",
    "An administrator invited you" : "En administratör bjöd in dig",
    "An administrator invited {federated_user}" : "En administratör bjöd in {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} godkände inbjudan",
    "{actor} removed {federated_user}" : "{actor} avlägsnade {federated_user}",
    "You removed {federated_user}" : "Du avlägsnade {federated_user}",
    "You declined the invitation" : "Du avböjde inbjudan",
    "An administrator removed {federated_user}" : "En administratör avlägsnade {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} avböjde inbjudan",
    "{actor} added group {group}" : "{actor} lade till grupp {group}",
    "You added group {group}" : "Du lade till grupp {group}",
    "An administrator added group {group}" : "En administratör lade till grupp {group}",
    "{actor} removed group {group}" : "{actor} tog bort gruppen {group}",
    "You removed group {group}" : "Du tog bort gruppen {group}",
    "An administrator removed group {group}" : "En administratör tog bort gruppen {group}",
    "{actor} added team {circle}" : "{actor} lade till team {circle}",
    "You added team {circle}" : "Du lade till team {circle}",
    "An administrator added team {circle}" : "En administratör lade till team {circle}",
    "{actor} removed team {circle}" : "{actor} tog bort team {circle}",
    "You removed team {circle}" : "Du tog bort team {circle}",
    "An administrator removed team {circle}" : "En administratör tog bort team {circle}",
    "{actor} added {phone}" : "{actor} la till {phone}",
    "You added {phone}" : "Du la till {phone}",
    "An administrator added {phone}" : "En administratör lade till {phone}",
    "{actor} removed {phone}" : "{actor} tog bort {phone}",
    "You removed {phone}" : "Du tog bort {phone}",
    "An administrator removed {phone}" : "En administratör tog bort {phone}",
    "{actor} promoted {user} to moderator" : "{actor} gjorde {user} till moderator",
    "You promoted {user} to moderator" : "Du gjorde {user} till moderator",
    "{actor} promoted you to moderator" : "{actor} gjorde dig moderator",
    "An administrator promoted you to moderator" : "En administratör gjorde dig till moderator",
    "An administrator promoted {user} to moderator" : "En administratör gjorde {user} till moderator",
    "{actor} demoted {user} from moderator" : "{actor} tog bort {user} som moderator",
    "You demoted {user} from moderator" : "Du tog bort {user} som moderator",
    "{actor} demoted you from moderator" : "{actor} tog bort dig som moderator",
    "An administrator demoted you from moderator" : "En administratör tog bort dig som moderator",
    "An administrator demoted {user} from moderator" : "En administratör tog bort {user} som moderator",
    "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
    "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
    "File shares are currently not supported in federated conversations" : "Fildelning stöds för närvarande inte i federerade konversationer",
    "The shared location is malformed" : "Den delade lokationen är felaktig",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} installera Matterbridge för att synkronisera den här konversationen med andra chattar",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Du installerar Matterbridge för att synkronisera den här konversationen med andra chattar",
    "{actor} created thread {title}" : "{actor} skapade tråden {title}",
    "You created thread {title}" : "Du skapade tråden {title}",
    "{actor} renamed thread {title}" : "{actor} bytte namn på tråden {title}",
    "You renamed thread {title}" : "Du bytte namn på tråden {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} uppdaterade Matterbridgekonfigurationen",
    "You updated the Matterbridge configuration" : "Du uppdaterade Matterbridgekonfigurationen",
    "{actor} removed the Matterbridge configuration" : "{actor} tog bort Matterbridgekonfigurationen",
    "You removed the Matterbridge configuration" : "Du tog bort Matterbridgekonfigurationen",
    "{actor} started Matterbridge" : "{actor}  startade Matterbridge",
    "You started Matterbridge" : "Du startade Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} stoppade Matterbridge",
    "You stopped Matterbridge" : "Du stoppade Matterbridge",
    "{actor} deleted a message" : "{actor} raderade ett meddelande",
    "You deleted a message" : "Du tog bort ett meddelande",
    "{actor} edited a message" : "{actor} redigerade ett meddelande",
    "You edited a message" : "Du redigerade ett meddelande",
    "{actor} pinned a message" : "{actor} fäste ett meddelande",
    "You pinned a message" : "Du fäste ett meddelande",
    "{actor} unpinned a message" : "{actor} tog bort fäst meddelande",
    "Message was automatically unpinned" : "Meddelandet togs automatiskt bort från fästa",
    "You unpinned a message" : "Du tog bort fäst meddelande",
    "{actor} deleted a reaction" : "{actor} tog bort en reaktion",
    "You deleted a reaction" : "Du tog bort en reaktion",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Du ställde in utgång av meddelande till %n vecka","Du ställde in utgång av meddelande till %n veckor"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Du ställde in utgång av meddelande till %n dag","Du ställde in utgång av meddelande till %n dagar"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Du ställde in utgång av meddelande till %n timme","Du ställde in utgång av meddelande till %n timmar"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Du ställde in utgång av meddelande till %n minut","Du ställde in utgång av meddelande till %n minuter"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} ställde in utgång av meddelande till %n vecka","{actor} ställde in utgång av meddelande till %n veckor"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} ställde in utgång av meddelande till %n dag","{actor} ställde in utgång av meddelande till %n dagar"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} ställde in utgång av meddelande till %n timme","{actor} ställde in utgång av meddelande till %n timmar"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} ställde in utgång av meddelande till %n minut","{actor} ställde in utgång av meddelande till %n minuter"],
    "{actor} disabled message expiration" : "{actor} inaktiverade utgång av meddelanden",
    "You disabled message expiration" : "Du inaktiverade utgång av meddelanden",
    "{actor} cleared the history of the conversation" : "{actor} rensade historiken av konversationen",
    "You cleared the history of the conversation" : "Du rensade historiken av konversationen",
    "{actor} set the conversation picture" : "{actor} ställde in konversationsbilden",
    "You set the conversation picture" : "Du ställde in konversationsbilden",
    "{actor} removed the conversation picture" : "{actor} tog bort konversationsbilden",
    "You removed the conversation picture" : "Du tog bort konversationsbilden",
    "{actor} ended the poll {poll}" : "{actor} tog bort undersökningen {poll}",
    "You ended the poll {poll}" : "Du avslutade undersökningen {poll}",
    "{actor} started the video recording" : "{actor} startade videoinspelningen",
    "You started the video recording" : "Du startade videoinspelningen",
    "{actor} stopped the video recording" : "{actor} stoppade videoinspelningen",
    "You stopped the video recording" : "Du stoppade videoinspelningen",
    "{actor} started the audio recording" : "{actor} startade ljudinspelningen",
    "You started the audio recording" : "Du startade ljudinspelningen",
    "{actor} stopped the audio recording" : "{actor} stoppade ljudinspelningen",
    "You stopped the audio recording" : "Du stoppade ljudinspelningen",
    "The recording failed" : "Inspelningen misslyckades",
    "Someone voted on the poll {poll}" : "Någon röstade på undersökningen {poll}",
    "Message deleted by author" : "Meddelandet togs bort av författaren",
    "Message deleted by {actor}" : "Meddelandet togs bort av {actor}",
    "Message deleted by you" : "Meddelandet togs bort av dig",
    "Deleted user" : "Borttagen användare",
    "Unknown number" : "Okänt nummer",
    "Administration" : "Administration",
    "System" : "System",
    "%s (guest)" : "%s (gäst)",
    "Missed call" : "Missat samtal",
    "Unanswered call" : "Obesvarat samtal",
    "Call ended (Duration {duration})" : "Samtal avslutat (Varaktighet {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Samtalet avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} avslutade samtalet (Varaktighet {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Samtal med %n gäst avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})","Samtal med %n gäster avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Samtal med %n gäst avslutat (Varaktighet {duration})","Samtal med %n gäster avslutat (Varaktighet {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} avslutade samtalet med %n gäst (Varaktighet {duration})","{actor} avslutade samtalet med %n gäster (Varaktighet {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Samtal med {user1} avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})",
    "Call with {user1} ended (Duration {duration})" : "Samtal med {user1} avslutades (Varaktighet {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} avslutade samtalet med {user1} (Varaktighet {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Samtal med {user1} och {user2} avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Samtal med {user1} och {user2} avslutat (Varaktighet {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} avslutade samtalet med {user1} och {user2} (Varaktighet {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} avslutat (Varaktighet {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} avslutade samtalet med {user1}, {user2} och {user3} (Varaktighet {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} avslutat (Varaktighet {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} avslutade samtalet med {user1}, {user2}, {user3} och {user4} (Varaktighet {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} avslutades eftersom det nådde den maximala samtalslängden (Varaktighet {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} avslutat (Varaktighet {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} avslutade samtalet med {user1}, {user2}, {user3}, {user4} och {user5} (Varaktighet {duration})",
    "Message of {user} in {conversation}" : "Meddelande av {user} i {conversation}",
    "Message of {user}" : "Meddelande av {user}",
    "Message of a deleted user in {conversation}" : "Meddelande av en borttagen användare i {conversation}",
    "Talk conversations" : "Talk-konversationer",
    "Call %s" : "Ring %s",
    "Chat with %s" : "Chatta med %s",
    "An error occurred. Please contact your administrator." : "Ett fel har uppstått. Vänligen kontakta din administratör.",
    "App disabled" : "App inaktiverad",
    "Conversation subfolders are disabled" : "Undermappar för konversationer är inaktiverade",
    "Storage quota exceeded" : "Lagringskvot överskriden",
    "Could not prepare conversation folder" : "Kunde inte förbereda konversationsmappen",
    "File not found" : "Filen kunde inte hittas",
    "Path must point to a file" : "Sökvägen måste peka på en fil",
    "File is not inside the conversation draft folder for this room" : "Filen finns inte i konversationens utkastsmapp för detta rum",
    "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
    "No account available to delete." : "Inget konto tillgängligt för att ta bort.",
    "Poll" : "Omröstning",
    "Password needs to be set" : "Lösenord måste ställas in",
    "Uploading the file failed" : "Det gick inte att ladda upp filen",
    "No image file provided" : "Ingen bildfil har tillhandahållts",
    "File is too big" : "Filen är för stor",
    "Invalid file provided" : "Ogiltig fil tillhandahölls",
    "Invalid image" : "Ogiltig bild",
    "Unknown filetype" : "Okänd filtyp",
    "Talk mentions" : "Talk-omnämnanden",
    "More conversations" : "Fler konversationer",
    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
    "No unread mentions" : "Inga olästa omnämnanden",
    "Call in progress" : "Samtal pågår",
    "You were mentioned" : "Du blev omnämnd",
    "Write to conversation" : "Skriv till konversation",
    "Writes event information into a conversation of your choice" : "Skriver händelseinformation till en konversation du väljer",
    "Missing email field in header line" : "E-postfält saknas i rubrikraden",
    "Following lines are invalid: %s" : "Följande rader är ogiltiga: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s bjöd in dig till konversationen \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Du blev inbjuden till konversationen \"%s\".",
    "Conversation invitation" : "Inbjudan till konversation",
    "Scheduled time" : "Schemalagd tid",
    "Description" : "Beskrivning",
    "You can also dial-in via phone with the following details" : "Det går också att ringa-upp via telefon med följande information",
    "Dial-in information" : "Uppringningsinformation",
    "Meeting ID" : "Mötes-ID",
    "Your PIN" : "Din pinkod",
    "Click the button below to join the lobby now." : "Klicka på knappen nedan för att gå med i lobbyn nu.",
    "Click the link below to join the lobby now." : "Klicka på länken nedan för att gå med i lobbyn nu.",
    "Join lobby for \"%s\"" : "Gå med i lobbyn för \"%s\"",
    "Click the button below to join the conversation now." : "Klicka på knappen nedan för att gå med i konversationen nu.",
    "Click the link below to join the conversation now." : "Klicka på länken nedan för att gå med i konversationen nu.",
    "Join \"%s\"" : "Gå med \"%s\"",
    "Meeting" : "Möte",
    "Password request: %s" : "Lösenordsförfrågan: %s",
    "Private conversation" : "Privat konversation",
    "Deleted user (%s)" : "Raderad användare (%s)",
    "Failed to upload call recording" : "Misslyckades med att ladda upp samtalsinspelning",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Inspelningsservern misslyckades med att ladda upp samtalsinspelningen {call}. Vänligen kontakta administrationen.",
    "Share to chat" : "Dela till chatt",
    "Dismiss notification" : "Avfärda notifiering",
    "Call recording now available" : "Samtalsinspelningen finns nu tillgänglig",
    "The recording for the call in {call} was uploaded to {file}." : "Inspelningen för samtalet i {call} blev uppladdat till {file}.",
    "Transcript now available" : "Transkript finns nu tillgänglig",
    "The transcript for the call in {call} was uploaded to {file}." : "Transkriptet för samtalet i {call} blev uppladdat till {file}.",
    "Failed to transcript call recording" : "Misslyckades att transkripta samtalsinspelningen",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Servern misslyckades att transkripta inspelningen på {file} för samtalet i {call}. Vänligen kontakta administrationen.",
    "Call summary now available" : "Samtalssammanfattning är nu tillgänglig",
    "The summary for the call in {call} was uploaded to {file}." : "Sammanfattningen för samtalet i {call} laddades upp till {file}.",
    "Failed to summarize call recording" : "Det gick inte att sammanfatta samtalsinspelningen",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Servern kunde inte sammanfatta inspelningen på {file} för samtalet i {call}. Vänligen kontakta din administratör.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} bjöd in dig att gå med i {roomName} på {remoteServer}",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "{user1} invited you to a federated conversation" : "{user1} bjöd in dig till en federerad konversation",
    "Someone reacted" : "Någon reagerade",
    "New message" : "Nytt meddelande",
    "Reminder" : "Påminnelse",
    "Someone mentioned you" : "Någon nämnde dig",
    "Notification" : "Notifiering",
    "Someone reacted in a private conversation" : "Någon reagerade i en privat konversation",
    "You received a message in a private conversation" : "Du fick ett meddelande i en privat konversation",
    "Reminder in a private conversation" : "Påminnelse i en privat konversation",
    "Someone mentioned you in a private conversation" : "Någon nämnde dig i en privat konversation",
    "Notification in a private conversation" : "Avisering i en privat konversation",
    "Reminder: You in {call}" : "Påminnelse: Du i {call}",
    "Reminder: {user} in {call}" : "Påminnelse: {user} i {call}",
    "Reminder: Deleted user in {call}" : "Påminnelse: Tog bort användare i {call}",
    "Reminder: {guest} (guest) in {call}" : "Påminnelse: {guest} (guest) i {call}",
    "Reminder: Guest in {call}" : "Påminnelse: Gäst i {call}",
    "{user} reacted with {reaction}" : "{user} reagerade med {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reagerade med {reaction} i {call}",
    "Deleted user reacted with {reaction} in {call}" : "Borttagen användare reagerade med {reaction} i {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (guest) reagerade med {reaction} i {call}",
    "Guest reacted with {reaction} in {call}" : "Gäst reagerade med {reaction} i {call}",
    "{user} in {call}" : "{user} i {call}",
    "Deleted user in {call}" : "Tog bort användare från {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) i {call}",
    "Guest in {call}" : "Gäst i {call}",
    "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
    "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
    "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gäst) skickade ett meddelande i konversationen {call}",
    "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
    "{user} replied to your private message" : "{user} svarade på ditt privata meddelande",
    "{user} replied to your message in conversation {call}" : "{user} svarade på ditt meddelande i konversationen {call}",
    "A deleted user replied to your message in conversation {call}" : "En raderad användare svarade på ditt meddelande i konversationen {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gäst) svarade på ditt meddelande i konversationen {call}",
    "A guest replied to your message in conversation {call}" : "En gäst svarade på ditt meddelande i konversationen {call}",
    "Reminder: You in private conversation {call}" : "Påminnelse: Du i privat konversation {call}",
    "Reminder: A deleted user in private conversation {call}" : "Påminnelse: En borttagend användare i en privat konversation {call}",
    "Reminder: {user} in private conversation" : "Påminnelse: {user} i privat konversation",
    "Reminder: You in conversation {call}" : "Påminnelse: Du i konversation {call}",
    "Reminder: {user} in conversation {call}" : "Påminnelse: {user} i konversation {call}",
    "Reminder: A deleted user in conversation {call}" : "Påminnelse: En borttagen användare i konversation {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Påminnelse: {guest} (guest) i konversation {call}",
    "Reminder: A guest in conversation {call}" : "Påminnelse: En gäst i konversation {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reagerade med {reaction} på ditt privata meddelande",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reagerade med {reaction} på ditt meddelande i konversationen {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "En borttagen användare reagerade med {reaction} på ditt meddelande i konversation {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (guest) reagerade med {reaction} på ditt meddelande i konversation {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "En gäst reagerade med {reaction} på ditt meddelande i konversation {call}",
    "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
    "{user} mentioned group {group} in conversation {call}" : "{user} nämnde gruppen {group} i konversationen {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} nämnde teamet {team} i konversationen {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} nämnde alla i konversation {call} ",
    "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "En borttagen användare nämnde gruppen  {group} i konversation {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "En raderad användare nämnde teamet {team} i konversationen {call}",
    "A deleted user mentioned everyone in conversation {call}" : "En raderad användare nämnde alla i konversation {call}",
    "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (guest) nämnde gruppen {group} i konversation {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (gäst) nämnde teamet {team} i konversationen {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (gäst) nämnde alla i konversationen {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gäst) nämnde dig i konversationen {call}",
    "A guest mentioned group {group} in conversation {call}" : "En gäst nämnde gruppen {group} i konversation {call}",
    "A guest mentioned team {team} in conversation {call}" : "En gäst nämnde teamet {team} i konversationen {call}",
    "A guest mentioned everyone in conversation {call}" : "En gäst nämnde alla i konversation {call}",
    "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
    "View message" : "Visa meddelande",
    "Dismiss reminder" : "Avvisa påminnelse",
    "View chat" : "Visa chatt",
    "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
    "Join call" : "Gå med i samtal",
    "Answer call" : "Svara på samtal",
    "{user} would like to talk with you" : "{user} vill prata med dig",
    "Call back" : "Ring tillbaka",
    "You missed a call from {user}" : "Du missade ett samtal från {user}",
    "Accept call" : "Acceptera samtal",
    "Incoming phone call from {call}" : "Inkommande telefonsamtal från {call}",
    "You missed a phone call from {call}" : "Du missade ett telefonsamtal från {call}",
    "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
    "You missed a group call in {call}" : "Du missade ett gruppsamtal i {call}",
    "{email} is requesting the password to access {file}" : "{email} begär lösenordet för åtkomst till {file}",
    "{email} tried to request the password to access {file}" : "{email} försökte begära lösenordet för åtkomst till {file}",
    "Someone is requesting the password to access {file}" : "Någon begär lösenordet för att komma åt {file}",
    "Someone tried to request the password to access {file}" : "Någon försökte begära lösenordet för att komma åt {file}",
    "Open settings" : "Öppna inställningar",
    "Hosted signaling server added" : "Hosted signalserver tillagd",
    "The hosted signaling server is now configured and will be used." : "Hosted signaling server är nu konfigurerad och kommer att användas.",
    "Hosted signaling server removed" : "Hosted signalserver borttagen",
    "The hosted signaling server was removed and will not be used anymore." : "Hosted signaling server blev borttagen och kommer inte användas längre",
    "Hosted signaling server changed" : "Hosted signalserver ändrad",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Kontot för Hosted signaling server ändrades med status från \"{oldstatus}\" till \"{newstatus}\".",
    "pending" : "Väntande",
    "active" : "aktiv",
    "expired" : "gått ut",
    "blocked" : "blockerad",
    "error" : "fel",
    "The certificate of {host} expires in {days} days" : "Certifikatet till {host} går ut om {days} dagar",
    "The certificate of {host} expired" : "Certifikatet till {host} har gått ut",
    "Contact via Talk" : "Kontakta via Talk",
    "Open Talk" : "Öppna Talk",
    "Call via Talk" : "Ring via Talk",
    "Default" : "Standard",
    "Send messages, create threads, and start voice and video calls." : "Skicka meddelanden, skapa trådar och starta röst- och videosamtal.",
    "Presentation" : "Presentation",
    "Restricted conversation for internal presentations." : "Begränsad konversation för interna presentationer.",
    "Voice room" : "Ljudrum",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Gå direkt med i samtalet, perfekt för avstämningar eller spontana möten.",
    "Webinar" : "Webbinarium",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Begränsad konversation med lobby aktiverad, idealisk för offentliga webbseminarier.",
    "Conversations" : "Konversationer",
    "Messages in current conversation" : "Meddelanden i aktuell konversation",
    "{user}" : "{user}",
    "Messages" : "Meddelanden",
    "{user} in {conversation}" : "{user} i {conversation}",
    "Messages in other conversations" : "Meddelanden i andra konversationer",
    "One-to-one rooms always need to show the other users avatar" : "Ett-till-ett-rum behöver alltid visa de andra användarnas avatar",
    "Invalid emoji character" : "Ogiltigt emojitecken",
    "Invalid background color" : "Ogiltig bakgrundsfärg",
    "Avatar image is not square" : "Profilbilden är inte fyrkantig",
    "Room {number}" : "Rum {number}",
    "Favorites" : "Favoriter",
    "Other" : "Annat",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Misslyckades med att begära en utvärdering eftersom utvärderingsservern ej är nåbar. Vänligen försök igen senare.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Det är problem med autentisieringen av den här instansen. Det kan vara att den inte är nåbar utifrån för att kunna verifiera IRL:en.",
    "Something unexpected happened." : "Något oväntat inträffade.",
    "The URL is invalid." : "URL:en är ogiltig.",
    "An HTTPS URL is required." : "En HTTPS URL krävs.",
    "The email address is invalid." : "E-postadressen är ogiltig.",
    "The language is invalid." : "Språket är ogiltigt.",
    "The country is invalid." : "Landet är ogiltigt.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Det är problem med förfrågan om utvärderingen. Vänligen kontrollera dina loggar för mer information.",
    "Too many requests are send from your servers address. Please try again later." : "För många förfrågningar är skickade från din serveradress. Vänligen försök igen senare.",
    "There is already a trial registered for this Nextcloud instance." : "Det finns redan en utvärdering registerad för den här Nexcloudinstansen.",
    "Something unexpected happened. Please try again later." : "Ett oväntat fel inträffade. Försök igen senare.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Misslyckades med att begära en utvärdering eftersom utvärderingsservern betedde sig felaktigt. Vänligen försök igen senare.",
    "Trial requested but failed to get account information. Please check back later." : "Utvärderingsförfrågan togs emot men misslyckades med att få kontoinformation. Vänligen försök igen senare.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Det är problem med autentisieringen av den här begäran. Det kan vara att den inte är nåbar utifrån för att kunna verifiera IRL:en.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Misslyckades med att motta kontoinformation eftersom utvärderingsservern betedde sig felaktigt. Vänligen försök igen senare.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Det är problem med att motta kontoinformation. Vänligen kontrollera dina loggar för mer information.",
    "There is no such account registered." : "Det finns inget sådan konto registrerat.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Misslyckades med att motta kontoinformation eftersom utvärderingsservern ej är nåbar. Vänligen försök igen senare.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Misslyckades med att ta bort signaling server kontot. Vänligen försök igen senare.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Misslhyckades med att ta bort kontot eftersom utvärderingsservern betedde sig felaktigt. Vänligen försök igen senare.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Det är problem med att ta bort kontot. Vänligen kontrollera dina inställningar för mer information.",
    "Too many requests are sent from your servers address. Please try again later." : "För många förfrågningar är skickade från din serveradress. Vänligen försök igen senare.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Misslyckades med att ta bort kontot eftersom utvärderingsservern inte är nåbar. Vänligen försök igen senare.",
    "Note to self" : "Egna anteckningar",
    "A place for your private notes, thoughts and ideas" : "En plats för dina privata anteckningar, tankar och idéer",
    "Transcript is AI generated and may contain mistakes" : "Transkriptionen är AI-genererad och kan innehålla misstag",
    "Summary is AI generated and may contain mistakes" : "Sammanfattningen är AI-genererad och kan innehålla misstag",
    "Let's get started!" : "Låt oss komma igång!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** är en säker, egenhostad kommunikationsplattform som integreras sömlöst med Nextclouds ekosystem.\n\n#### Huvudfunktioner i Nextcloud Talk:\n\n* Chatt och meddelanden i privata och gruppchattar\n* Röst och videosamtal\n* Fildelning och integration med andra Nextcloud-appar\n* Anpassningsbara konversationsinställningar, moderering och sekretesskontroller\n* Webb, dator och mobil (iOS och Android)\n* Privat och säker kommunikation\n\n Läs mer i [användardokumentationen](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Välkommen till Nextcloud Talk\n\nNextcloud Talk är en privat och kraftfull meddelandeapp som integreras med Nextcloud. Chatta i privata eller gruppkonversationer, samarbeta via röst- och videosamtal, organisera webbinarier och evenemang, anpassa dina konversationer och mycket mer.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formatera texter för att skapa innehållsrika meddelanden\n\nI Nextcloud Talk kan du använda Markdown-syntax för att formatera dina meddelanden. Till exempel kan du använda **fetstil** eller *kursiv*, eller `markera text som kod`. Du kan till och med skapa tabeller och lägga till rubriker i din text.\n\nBehöver du rätta ett stavfel eller ändra formatering? Redigera ditt meddelande genom att klicka på “Redigera meddelande” i meddelandemenyn.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Lägg till bilagor och länkar\n\nBifoga filer från din Nextcloud Hub med hjälp av “+”-knappen. Dela objekt från Filer och olika Nextcloud-appar. Vissa appar stödjer till och med interaktiva widgets, till exempel Text-appen.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Låt konversationerna flöda: nämn användare, reagera på meddelanden och mycket mer\n\nDu kan nämna alla i konversationen genom att använda %s eller nämna enskilda deltagare genom att skriva “@” och välja deras namn från listan.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Du kan svara på meddelanden, vidarebefordra dem till andra chattar och personer eller kopiera meddelandeinnehållet.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Gör mer med Smart Picker\n\nSkriv “/” eller gå till “+”-menyn för att öppna Smart Picker, där du kan bifoga olika typer av innehåll till dina meddelanden. Du kan konfigurera Smart Picker för att kunna lägga till objekt från Nextcloud-appar, GIF:ar, platsinformation från kartor, AI-genererat innehåll och mycket mer.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Hantera konversationsinställningar\n\nI konversationsmenyn kan du komma åt olika inställningar för att hantera dina konversationer, såsom:\n* Redigera konversationsinformation\n* Hantera aviseringar\n* Tillämpa flera modereringsregler\n* Konfigurera åtkomst och säkerhet\n* Aktivera bottar\n* och mycket mer!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Förenade arabemiraten",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua och Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikanska Samoa",
    "Austria" : "Österrike",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbajdzjan",
    "Bosnia and Herzegovina" : "Bosnien och Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolivia, den mångnationella staten",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Vitryssland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Congo, the Democratic Republic of the" : "Kongo, den republikanska republiken",
    "Central African Republic" : "Centralafrikanska republiken",
    "Congo" : "Kongo, Republiken (Brazzaville)",
    "Switzerland" : "Schweiz",
    "Côte d'Ivoire" : "Elfenbenskusten",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Julön",
    "Cyprus" : "Cypern",
    "Czechia" : "Tjeckien",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominikanska republiken",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypten",
    "Western Sahara" : "Västsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Etiopien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falklandsöarna (Malvinas)",
    "Micronesia, Federated States of" : "Mironesien, den Mikronesiska federationen",
    "Faroe Islands" : "Färöarna",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Förenade konungariket Storbritannien och Nordirland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Franska Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Grekland",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island och McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungern",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, den islamska republiken",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Korea, den Demokratiska Folkrepubliken",
    "Korea, Republic of" : "Sydkorea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakstan",
    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marocko",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldavien",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall Islands",
    "North Macedonia" : "Nordmakedonien",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongoliet",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiverna",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nya Kaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederländerna",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nya Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franska Polynesien",
    "Papua New Guinea" : "Papua Nya Guinea",
    "Philippines" : "Filippinerna",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine, State of",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Salomonöarna",
    "Seychelles" : "Seychellerna",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenien",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakien",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "South Sudan",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Eswatini" : "Swaziland",
    "Turks and Caicos Islands" : "Turks- och Caicosöarna",
    "Chad" : "Chad",
    "French Southern Territories" : "Franska södra territorierna",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisien",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiet",
    "Trinidad and Tobago" : "Trinidad och Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela, den Bolivarianska republiken",
    "Virgin Islands, British" : "Jungfruöarna, Brittiska",
    "Virgin Islands, U.S." : "Jungfruöarna, Amerikanska",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sydafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Suddig bakgrund",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Kunde inte kontrollera stöd för laddning av WASM. Kontrollera manuellt om din webbserver tillhandahåller .wasm-filer.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Din webbserver är inte korrekt konfigurerad för att leverera .wasm-filer. Detta är vanligtvis ett problem med Nginx-konfigurationen. För att suddig bakgrund ska fungera behöver konfigurationen justeras så att den även levererar .wasm-filer. Jämför din Nginx-konfiguration med den rekommenderade konfigurationen i vår dokumentation.",
    "Talk configuration values" : "Talk konfigurationsvärden",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Att tvinga fram en samtalslängd stöds endast med systemets cron. Aktivera system cron eller ta bort konfigurationen `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Små \"max_call_duration\"-värden (för närvarande inställda på %d) kan inte tillämpas på grund av tekniska begränsningar. Bakgrundsjobbet utförs endast var 5:e minut, så använd på egen risk.",
    "Federation" : "Federation",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Det rekommenderas starkt att konfigurera \"memcache.locking\" när Talk Federation är aktiverat.",
    "High-performance backend" : "High-performance backend",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Ingen High-performance backend konfigurerad - Att köra Nextcloud Talk utan High-performance backend skalar endast för mycket små samtal (max. 2-3 deltagare). Konfigurera High-performance backend för att säkerställa att samtal med flera deltagare fungerar sömlöst.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Att köra med High-performance backend \"conversation_cluster\" läge är utfasat och kommer inte längre att stödjas i den kommande versionen. High-performance backend stöder real clustering nuförtiden som bör användas istället.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Att definiera flera High-performance backends är föråldrat och kommer inte längre att stödjas i den kommande versionen. Istället bör en lastbalanserare ställas in tillsammans med klustrade signalservrar och konfigureras i Talk-inställningarna.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Den sparade publika nyckeln för den använda algoritmen %1$s matchar inte den sparade privata nyckeln. Kör %2$s för att åtgärda problemet.",
    "High-performance backend not configured correctly. Run %s for details." : "High-performance backend är inte korrekt konfigurerad. Kör %s för detaljer.",
    "High-performance backend not configured correctly" : "High-performance backend är inte korrekt konfigurerad",
    "Error: Cannot connect to server" : "Error: Kan inte ansluta till server",
    "Error: Server did not respond with proper JSON" : "Error: Servern svarade inte med korrekt JSON",
    "Error: Certificate expired" : "Error: Certifikatet har gått ut",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Fel: Systemtiderna för Nextcloud-servern och högpresterande backend-server är osynkroniserade. Se till att båda servrarna är anslutna till en tidsserver eller synkronisera deras tid manuellt.",
    "Could not get version" : "Det gick inte att hämta versionen",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Fel: Kör version: {version}; Servern måste uppdateras för att vara kompatibel med den här versionen av Talk",
    "Error: Server responded with: {error}" : "Error: Servern svarade med: {error}",
    "Error: Unknown error occurred" : "Error: Okänt fel inträffade",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Varning: Aktuell version: {version}; Servern stöder inte alla funktioner i denna Talk-version, funktioner saknas: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Det rekommenderas starkt att konfigurera en minnescache när du kör Nextcloud Talk med en High-performance backend.",
    "Client Push" : "Klient-Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push är installerat, vilket gör Talk-aviseringar mer tillförlitliga.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} är inte installerat. Detta kan leda till fördröjda Talk-aviseringar.",
    "Recording backend" : "Recording backend",
    "Using the recording backend requires a High-performance backend." : "För att kunna använda recording backend krävs en High-performance backend.",
    "No recording backend configured" : "Ingen recording backend konfigurerad",
    "SIP configuration" : "SIP-konfiguration",
    "Using the SIP functionality requires a High-performance backend." : "Användning av SIP-funktionalitet kräver en High-performance backend.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Tilldelade Talk-telefonnummer får inte börja med + eller 0. Ta bort eller uppdatera följande nummer:\n{list}",
    "No SIP backend configured" : "Ingen SIP-backend konfigurerad",
    "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
    "Conversation not found" : "Konversationen hittades inte",
    "Path is already shared with this conversation" : "Sökvägen är redan delad med denna konversation",
    "Chat, video & audio-conferencing using WebRTC" : "Chatt, video och ljud - konferenser med WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chatt, video och ljudkonferenser med WebRTC\n\n* 💬 **Chat** Nextcloud Talk kommer med en enkel textchatt, så att du kan dela eller ladda upp filer från din Nextcloud Files-app eller lokala enhet och nämna andra deltagare.\n* 👥 **Privata, grupp, publika och lösenordsskyddade samtal!** Bjud in någon, en hel grupp eller skicka en publik länk för att bjuda in till ett samtal.\n* 🌐 **Federerade chattar** Chatta med andra Nextcloud-användare på deras servrar\n* 💻 **Skärmdelning!** Dela din skärm med deltagarna i ditt samtal.\n* 🚀 **Integration med andra Nextcloud-appar** som Filer, Kalender, Användarstatus, Dashboard, Flow, Kartor, Smart picker, Kontakter, Deck och många fler.\n* 🌉 **Synkronisera med andra chattlösningar** Med [Matterbridge](https://github.com/42wim/matterbridge/) integrerad i Talk kan du enkelt synkronisera många andra chattlösningar till Nextcloud Talk och vice versa.",
    "Leave call" : "Lämna samtalet",
    "Navigating away from the page will leave the call in {conversation}" : "Navigera bort från sidan kommer att lämna samtalet {conversation}",
    "Stay in call" : "Stanna i samtal",
    "Error occurred when getting the conversation information" : "Ett fel uppstod vid hämtning av konversationsinformationen",
    "Duplicate session" : "Duplicerade sessioner",
    "Discuss this file" : "Diskutera den här filen",
    "Loading …" : "Laddar ...",
    "Share this file with others to discuss it" : "Dela den här filen med andra för att diskutera",
    "Join conversation" : "Gå med i konversation",
    "Share this file" : "Dela den här filen",
    "Error occurred when joining the conversation" : "Ett fel uppstod vid anslutning av konversationen",
    "Open in full application" : "Öppna i fullständig applikation",
    "This conversation is password-protected." : "Konversationen är lösenordsskyddad.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Password" : "Lösenord",
    "Submit" : "Skicka",
    "Error requesting the password." : "Fel vid begäran av lösenord.",
    "Request password" : "Begär lösenord",
    "This conversation has ended" : "Denna konversation har avslutats",
    "Close Talk sidebar" : "Stäng Talk sidofält",
    "Open Talk sidebar" : "Öppna Talk sidofält",
    "Everyone" : "Alla",
    "Users and moderators" : "Användare och moderatorer",
    "Moderators only" : "Endast moderatorer",
    "Disable calls" : "Inaktivera samtal",
    "Save changes" : "Spara ändringar",
    "Saving …" : "Sparar ...",
    "Saved!" : "Sparat!",
    "Limit to groups" : "Begränsa till grupper",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "När minst en grupp väljs kan bara personer i de angivna grupperna ingå i konversationer.",
    "Guests can still join public conversations." : "Gäster kan fortfarande delta i publika konversationer.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Användare som inte kan använda Talk längre kommer fortfarande att listas som deltagare i sina tidigare samtal och även deras chattmeddelanden kommer att behållas.",
    "Limit using Talk" : "Begränsa använda Talk",
    "Limit creating a public and group conversation" : "Begränsa att skapa en allmän och gruppkonversation",
    "Limit creating conversations" : "Begränsa att skapa konversationer",
    "Limit starting a call" : "Begränsa att starta ett samtal",
    "Limit starting calls" : "Begränsa att starta samtal",
    "When a call has started, everyone with access to the conversation can join the call." : "När ett samtal har startat kan alla som har åtkomst till konversationen gå med i samtalet.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Följande bottar är installerade på denna server. I dokumentationen kan du hitta detaljer om hur du {linkstart1}bygger din egen bott{linkend} eller en {linkstart2}lista av bottar{linkend} för att aktivera på din server.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Inga bottar är installerad på denna server. I dokumentationen kan du hitta detaljer om hur du {linkstart1}bygger din egen bott{linkend} eller en {linkstart2}lista av bottar{linkend} för att aktivera på din server.",
    "Description is not provided" : "Beskrivning fattas",
    "Locked for moderators" : "Låst för moderatorer",
    "Enabled" : "Aktiverad",
    "Disabled" : "Inaktiverad",
    "Bots settings" : "Inställningar för bottar",
    "State" : "Status",
    "Name" : "Namn",
    "Last error" : "Senaste fel",
    "Total errors count" : "Totalt antal fel",
    "Find more bots" : "Hitta fler bottar",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Betrodda servrar kan konfigureras på {linkstart}Sidan delningsinställningar{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Federerade chattar och samtal fungerar redan. Hantering av bilagor kommer i en framtida version.",
    "Enable Federation in Talk app" : "Aktivera federation i Talk-appen",
    "Permissions" : "Behörigheter",
    "Allow users to be invited to federated conversations" : "Tillåt användare att bjudas in till federerade konversationer",
    "Allow users to invite federated users into conversation" : "Tillåt användare att bjuda in federerade användare till konversation",
    "Only allow to federate with trusted servers" : "Tillåt endast federation med betrodda servrar",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "När minst en grupp är vald kan bara personer i de listade grupperna bjuda in federerade användare till konversationer.",
    "Groups allowed to invite federated users" : "Grupper som får bjuda in federerade användare",
    "Select groups …" : "Välj grupper ...",
    "All messages" : "Alla meddelanden",
    "@-mentions only" : "@-mentions only",
    "Off" : "Av",
    "General settings" : "Allmänna inställningar",
    "Default notification settings" : "Standardinställningar meddelanden",
    "Default group notification" : "Standard gruppmeddelande",
    "Default group notification for new groups" : "Standard gruppmeddelande för nya grupper",
    "Integration into other apps" : "Integration med andra appar",
    "Allow conversations on files" : "Tillåt konversationer på filer",
    "Allow conversations on public shares for files" : "Tillåt konversationer på offentliga delningar för filer",
    "End-to-end encrypted calls" : "End-to-end-krypterade samtal",
    "Enable encryption" : "Aktivera kryptering",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "End-to-end-krypterade samtal med en konfigurerad SIP-brygga kräver en nyare version av high-performance backend och SIP-brygga.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Mobila klienter stöder för närvarande inte end-to-end-krypterade samtal.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Genom att klicka på knappen ovanför skickas informationen i formuläret till Struktur AG:s servrar. Du hittar mer information på {linkstart}spreed.eu{linkend}.",
    "Pending" : "Avvaktar",
    "Error" : "Fel",
    "Blocked" : "Blockerar",
    "Active" : "Aktiv",
    "Expired" : "Utgånget",
    "Never" : "Aldrig",
    "The trial could not be requested. Please try again later." : "Provperiod kunde inte begäras. Vänligen försök igen senare.",
    "The account could not be deleted. Please try again later." : "Kontot kunde inte raderas. Försök igen senare.",
    "Hosted High-performance backend" : "Hosted High-performance backend",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Vår partner Struktur AG tillhandahåller en tjänst där en hostad signalserver kan begäras. För detta behöver du bara fylla i formuläret nedan och din Nextcloud kommer sedan att skicka begäran. När servern är konfigurerad kommer användaruppgifterna att fyllas i automatiskt. Detta kommer att skriva över de befintliga signalserverinställningarna.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Om ditt konto för high-performance-backend inkluderar STUN- och/eller TURN-funktionalitet, kommer inställningarna att uppdateras därefter.",
    "URL of this Nextcloud instance" : "URL till denna Nextcloud-instans",
    "Full name of the user requesting the trial" : "Fullständigt namn på användaren som begär provperioden",
    "Email of the user" : "Användarens e-post",
    "Language" : "Språk",
    "Country" : "Land",
    "Request signaling server trial" : "Begär testversion av signalserver",
    "You can see the current status of your hosted signaling server in the following table." : "Du kan se aktuell status för din hostade signalserver i följande tabell.",
    "Status" : "Status",
    "Created at" : "Skapad",
    "Expires at" : "Går ut",
    "Limits" : "Begränsningar",
    "STUN included" : "STUN ingår",
    "Yes" : "Ja",
    "No" : "Nej",
    "TURN included" : "TURN ingår",
    "Delete the signaling server account" : "Ta bort signalserverkontot",
    "_%n user_::_%n users_" : ["%n användare","%n användare"],
    "Installed version: {version}" : "Installerad version: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Du kan installera Matterbridge för att länka Nextcloud Talk till några andra tjänster, besök deras {linkstart1}GitHub-sida{linkend} för mer information. Att ladda ner och installera appen kan ta ett tag. Vid timeout, installera den manuellt från {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge binär har felaktiga behörigheter. Se till att den binära Matterbridge-filen ägs av rätt användare och kan köras. Den finns i \"/.../nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge binär hittades inte eller kunde inte köras.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Du kan också ställa in sökvägen till Matterbridge-binären manuellt via konfigurationen. Se {linkstart}Matterbridge integrationsdokumentation{linkend} för mer information.",
    "Downloading …" : "Hämtar …",
    "Install Talk Matterbridge" : "Installera Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Ett fel uppstod när Matterbridge-appen skulle installeras",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Ett fel uppstod när Talk Matterbridge skulle installeras. Installera den manuellt",
    "Failed to execute Matterbridge binary." : "Det gick inte att köra Matterbridge binär.",
    "Matterbridge integration" : "Matterbridge-integration",
    "Enable Matterbridge integration" : "Aktivera Matterbridge-integration",
    "Status: Checking connection" : "Status: Kontrollerar anslutning",
    "OK: Running version: {version}" : "OK: Kör version: {version}",
    "Error: Server seems to be a Signaling server" : "Fel: Servern verkar vara en signalserver",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Fel: Systemtiderna för Nextcloud-servern och Recording-backend-servern är osynkroniserade. Se till att båda servrarna är anslutna till en tidsserver eller synkronisera deras tid manuellt.",
    "Recording backend URL" : "Recording backend-URL",
    "Validate SSL certificate" : "Validera SSL-certifikat",
    "Delete this server" : "Ta bort denna server",
    "Test this server" : "Testa denna server",
    "Disabled for all calls" : "Inaktiverad för alla samtal",
    "Enabled for all calls" : "Aktiverad för alla samtal",
    "Configurable on conversation level by moderators" : "Anpassningsbar på konversationsnivå av moderatorer",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP-inställningarna \"upload_max_filesize\" eller \"post_max_size\" tillåter endast att ladda upp filer upp till {maxUpload}.",
    "Recording backend settings saved" : "Inställningar för recording backend har sparats",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderatorer kommer att tillåtas aktivera samtycke på konversationsnivå. Samtycket om inspelning kommer att krävas för varje deltagare innan de går med i varje samtal i denna konversation.",
    "The consent to be recorded will be required for each participant before joining every call." : "Samtycket om inspelning kommer att krävas för varje deltagare innan de går med i varje samtal.",
    "The consent to be recorded is not required." : "Samtycke för att spela in krävs inte.",
    "Recording backend configuration is only possible with a High-performance backend." : "Recording backend-konfiguration är endast möjlig med en High-performance backend.",
    "Add a new recording backend server" : "Lägg till en ny recording backend-server",
    "Shared secret" : "Delad hemlighet",
    "Recording consent" : "Samtycke för inspelning",
    "Recording transcription" : "Inspelning av transkription",
    "Automatically transcribe call recordings with a transcription provider" : "Transkribera samtalsinspelningar automatiskt med en transkriptionsleverantör",
    "Automatically summarize call recordings with transcription and summary providers" : "Sammanfatta automatiskt samtalsinspelningar med transkriptions- och sammanfattningsleverantörer",
    "SIP configuration saved!" : "SIP-konfigurationen sparad!",
    "SIP configuration is only possible with a High-performance backend." : "SIP-konfiguration är endast möjlig med en High-performance backend.",
    "Enable SIP Dial-out option" : "Aktivera SIP-uppringningsalternativ",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signalservern behöver uppdateras för att stödja SIP-uppringningsfunktionen.",
    "Do not show SIP Dial-out caller number" : "Visa inte SIP uppringarens nummer vid utgående samtal",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Anonymt nummer ska visas som “okänd” eller “hemligt nummer” för den som tar emot samtalet",
    "Dial-out number" : "Utgående nummer",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "E164-formaterat nummer som används som reservnummer vid utgående samtal",
    "Dial-out prefix" : "Prefix för utgående samtal",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefix till det konfigurerade användarnumret för utgående samtal (standard är `+`)",
    "Restrict SIP configuration" : "Begränsa SIP-konfiguration",
    "Enable SIP configuration" : "Aktivera SIP-konfiguration",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Endast användare av följande grupper kan aktivera SIP i konversationer som de modererar",
    "Phone number (Country)" : "Telefonnummer (land)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Denna information skickas i e-postinbjudningar samt visas i sidofältet för alla deltagare.",
    "Nextcloud base URL" : "Nextcloud bas-URL",
    "Talk Backend URL" : "Talk Backend-URL",
    "WebSocket URL" : "WebSocket-URL",
    "Available features" : "Tillgängliga funktioner",
    "Error: Websocket connection failed" : "Fel: Websocket-anslutning misslyckades",
    "Error code" : "Felkod",
    "Error message" : "Felmeddelande",
    "Error: Websocket connection failed. Check browser console" : "Fel: Websocket-anslutning misslyckades. Kontrollera webbläsarkonsolen",
    "High-performance backend URL" : "High-performance backend-URL",
    "Missing High-performance backend warning hidden" : "Varning för saknad High-performance backend är dold",
    "High-performance backend settings saved" : "Inställningar för high-performance backend har sparats",
    "Nextcloud Talk setup not complete" : "Nextcloud Talk-installationen är inte klar",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Observera att i samtal med fler än 2 deltagare utan High-performance backend kommer deltagarna med största sannolikhet att uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Installera High-performance backend för att säkerställa att samtal med flera deltagare fungerar sömlöst.",
    "Nextcloud portal" : "Nextcloud portal",
    "Quick installation guide" : "Snabb installationsguide",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "High-performance backend krävs för samtal och konversationer med flera deltagare. Utan detta så måste alla deltagare ladda upp sin egen video individuellt för varje annan deltagare, vilket med största sannolikhet kommer att orsaka anslutningsproblem och en hög belastning på deltagande enheter.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Det rekommenderas starkt att sätta upp en distribuerad cache när du använder Nextcloud Talk med en High-performance backend.",
    "Add High-performance backend server" : "Lägg till High-performance backend-server",
    "Warn about connectivity issues in calls with more than 2 participants" : "Varna om anslutningsproblem i samtal med fler än 2 deltagare",
    "STUN server URL" : "STUN server-URL",
    "The server address is invalid" : "Serveradressen är ogiltig",
    "STUN settings saved" : "STUN-inställningar sparade",
    "STUN servers" : "STUN-servrar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
    "Add a new STUN server" : "Lägg till en ny STUN-server",
    "{schema} scheme must be used with a domain" : "{schema} schema måste användas med en domän",
    "{option1} and {option2}" : "{option1} och {option2}",
    "{option} only" : "endast {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: ICE-kandidater returneras av TURN-servern",
    "Error: No working ICE candidates returned by the TURN server" : "Fel: Inga fungerande ICE-kandidater returneras av TURN-servern",
    "Testing whether the TURN server returns ICE candidates" : "Testar om TURN-servern returnerar ICE-kandidater",
    "TURN server schemes" : "TURN-server scheman",
    "TURN server URL" : "TURN server-URL",
    "TURN server secret" : "TURN-server hemlighet",
    "TURN server protocols" : "TURN-server protokoll",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "En TURN-server används för att proxa trafiken från deltagare bakom en brandvägg. Om enskilda deltagare inte kan ansluta till andra är en TURN-server troligtvis nödvändig. Se {linkstart}denna dokumentation{linkend} för installationsinstruktioner.",
    "TURN settings saved" : "TURN-inställningar sparade",
    "TURN servers" : "TURN-servrar",
    "Add a new TURN server" : "Lägg till en ny TURN-server",
    "Failed" : "Misslyckades",
    "OK" : "OK",
    "Checking …" : "Kontrollerar...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Misslyckades: WebAssembly är inaktiverat eller stöds inte i den här webbläsaren. Aktivera WebAssembly eller använd en webbläsare med stöd för att utföra kontrollen.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Misslyckades: \".wasm\"- och \".tflite\"-filer returnerades inte korrekt av webbservern. Kontrollera avsnittet \"Systemkrav\" i Talk-dokumentationen.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\"- och \".tflite\"-filer returnerades korrekt av webbservern.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Det verkar som att PHP- och Apache-konfigurationen inte är kompatibel. Observera att PHP endast kan användas med modulen MPM_PREFORK och PHP-FPM kan endast användas med modulen MPM_EVENT.",
    "Web server setup checks" : "Kontroller av webbserverinställningar",
    "Files required for virtual background can be loaded" : "Filer som krävs för virtuell bakgrund kan laddas",
    "Federated user" : "Federerad användare",
    "Assign participants to rooms" : "Tilldela deltagare till rum",
    "Configure breakout rooms" : "Konfigurera grupprum",
    "Number of breakout rooms" : "Antal grupprum",
    "You can create from 1 to 20 breakout rooms." : "Du kan skapa från 1 till 20 grupprum.",
    "Assignment method" : "Tilldelningsmetod",
    "Automatically assign participants" : "Tilldela deltagare automatiskt",
    "Manually assign participants" : "Tilldela deltagare manuellt",
    "Allow participants to choose" : "Låt deltagarna välja",
    "Create rooms" : "Skapa rum",
    "Confirm" : "Bekräfta",
    "Create breakout rooms" : "Skapa grupprum",
    "Reset" : "Återställ",
    "Delete breakout rooms" : "Ta bort grupprum",
    "Room {roomNumber}" : "Rum {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Aktuella grupprum och inställningar kommer att gå förlorade",
    "Cancel" : "Avbryt",
    "Unassigned participants" : "Ej tilldelade deltagare",
    "Back" : "Tillbaka",
    "Assign" : "Tilldela",
    "Add participant \"{user}\"" : "Lägg till deltagare \"{user}\"",
    "Now" : "Nu",
    "Invalid calendar selected" : "Ogiltig kalender vald",
    "Invalid start time selected" : "Ogiltig starttid vald",
    "Invalid end time selected" : "Ogiltig sluttid vald",
    "Unknown error occurred" : "Okänt fel inträffade",
    "Sending no invitations" : "Skickar inga inbjudningar",
    "{participant0} will receive an invitation" : "{participant0} kommer att få en inbjudan",
    "{participant0} and {participant1} will receive invitations" : "{participant0} och {participant1} kommer att få inbjudningar",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} och %n annan kommer att få inbjudningar","{participant0}, {participant1} och %n andra kommer att få inbjudningar"],
    "Invite {user}" : "Bjud in {user}",
    "Invite all users and emails in this conversation" : "Bjud in alla användare och e-postadresser till den här konversationen",
    "Meeting created" : "Möte skapat",
    "Upcoming meetings" : "Kommande möten",
    "No upcoming meetings" : "Inga kommande möten",
    "Schedule a meeting" : "Schemalägg ett möte",
    "Meeting title" : "Mötes titel",
    "From" : "Från",
    "To" : "Till",
    "Calendar" : "Kalender",
    "Attendees" : "Deltagare",
    "No other participants to send invitations to." : "Inga andra deltagare att skicka inbjudningar till.",
    "Add attendees" : "Lägg till deltagare",
    "Save" : "Spara",
    "Search participants" : "Sök deltagare",
    "No results" : "Inga resultat",
    "Done" : "Klar",
    "Disable live transcription" : "Inaktivera live-transkribering",
    "Enable live transcription (generated by AI)" : "Aktivera live-transkribering (genereras av AI)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Aktivera live-transkribering (appen Live Transcriptions är inte installerad)",
    "Disable live translation" : "Inaktivera live-översättning",
    "Enable live translation (generated by AI)" : "Aktivera live-översättning (genereras av AI)",
    "Original language" : "Originalspråk",
    "Live translations app is not installed" : "Appen Live translations är inte installerad",
    "Original language: {languageName}" : "Originalspråk: {languageName}",
    "Translated language" : "Översatt språk",
    "Translated language: {languageName}" : "Översatt språk: {languageName}",
    "Exit full screen (F)" : "Avsluta fullskärm (F)",
    "Full screen (F)" : "Fullskärm (F)",
    "Speaker view" : "Presentationsvy",
    "Grid view" : "Rutnätsvy",
    "Error when trying to load the available live transcription languages" : "Fel vid försök att läsa in tillgängliga språk för live-transkribering",
    "Failed to enable live transcription" : "Kunde inte aktivera live-transkribering",
    "Failed to enable live translations" : "Kunde inte aktivera live-översättning",
    "Failed to disable live translations" : "Kunde inte inaktivera live-översättning",
    "Recording consent is required" : "Samtycke för inspelning krävs",
    "This conversation is read-only" : "Den här konversationen är skrivskyddad",
    "Conversation not found or not joined" : "Konversationen hittades inte eller gick inte att gå med",
    "Lobby is still active and you're not a moderator" : "Lobbyn är fortfarande aktiv och du är inte moderator",
    "Connection failed" : "Anslutningen misslyckades",
    "Reload" : "Ladda om",
    "{nickName} raised their hand." : "{nickName} räckte upp handen.",
    "A participant raised their hand." : "En deltagare räckte upp handen.",
    "Collapse stripe" : "Minimera fält",
    "Expand stripe" : "Expandera fält",
    "Previous page of videos" : "Föregående sida med videor",
    "Next page of videos" : "Nästa sida med videor",
    "Connecting …" : "Ansluter…",
    "Calling …" : "Ringer …",
    "Waiting for {user} to join the call" : "Väntar på att {user} ska gå med i samtalet",
    "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
    "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
    "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
    "Copy link" : "Kopiera länk",
    "You are not allowed to enable audio" : "Du får inte aktivera ljud",
    "No audio. Click to select device" : "Inget ljud. Klicka för att välja enhet",
    "Mute audio" : "Stäng av ljudet",
    "Mute audio (M)" : "Stäng av ljud (M)",
    "Unmute audio" : "Aktivera ljud",
    "Unmute audio (M)" : "Aktivera ljud (M)",
    "None" : "Ingen",
    "Select a microphone" : "Välj en mikrofon",
    "Select a speaker" : "Välj en högtalare",
    "Microphone settings" : "Mikrofoninställningar",
    "Check devices" : "Kontrollera enheter",
    "Access to camera was denied" : "Åtkomst till kamera nekades",
    "Error while accessing camera: It is likely in use by another program" : "Fel vid åtkomst till kameran: Den används troligen av ett annat program",
    "Error while accessing camera" : "Fel vid åtkomst till kameran",
    "You have been muted by a moderator" : "Du har tystats av en moderator",
    "Hide presenter video" : "Dölj presentatörsvideo",
    "You are not allowed to enable video" : "Du får inte aktivera video",
    "No video. Click to select device" : "Ingen video. Klicka för att välja enhet",
    "Disable video" : "Stäng av video",
    "Disable video (V)" : "Inaktivera video (V)",
    "Enable video" : "Aktivera video",
    "Enable video (V)" : "Aktivera video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video - Din anslutning får ett kort avbrott när du aktiverar video första gången",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video (V) - Din anslutning får ett kort avbrott när du aktiverar videon för första gången",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video. Din anslutning får ett kort avbrott när du aktiverar video första gången",
    "Select a video device" : "Välj en videoenhet",
    "Show presenter" : "Visa presentatör",
    "You" : "Du",
    "Mute" : "Tyst",
    "Muted" : "Tyst",
    "Show screen" : "Visa skärm",
    "Stop following" : "Sluta följa",
    "Connection could not be established …" : "Anslutningen kunde inte upprättas ...",
    "Connection was lost and could not be re-established …" : "Anslutningen förlorades och kunde inte återupprättas ...",
    "Connection could not be established. Trying again …" : "Det gick inte att upprätta anslutning. Försöker igen ...",
    "Connection lost. Trying to reconnect …" : "Anslutning förlorad. Försöker återansluta ...",
    "Connection problems …" : "Anslutningsproblem ...",
    "Collapse" : "Dölj",
    "Expand" : "Utöka",
    "You need to be logged in to upload files" : "Du måste vara inloggad för att ladda upp filer",
    "Drop your files to upload" : "Släpp dina filer för att ladda upp",
    "Conversation messages" : "Konversationsmeddelanden",
    "Scroll to bottom" : "Bläddra till botten",
    "Post message" : "Skicka meddelande",
    "Federated conversation" : "Federerad konversation",
    "Public conversation" : "Publik konversation",
    "Favorite" : "Favorit",
    "Banned users" : "Blockerade användare",
    "Manage the list of banned users in this conversation." : "Hantera listan över blockerade användare i den här konversationen.",
    "Manage bans" : "Hantera blockeringar",
    "No banned users" : "Inga blockerade användare",
    "Banned by:" : "Blockerad av:",
    "Date:" : "Datum:",
    "Note:" : "Notering:",
    "Hide details" : "Göm detaljer",
    "Show details" : "Visa detaljer",
    "Unban" : "Tillåt",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Du kan ändra titeln och beskrivningen i {linkstart}Kalender ↗{linkend}.",
    "Error while updating conversation name" : "Fel uppstod när namnet på konversationen skulle uppdateras",
    "Error while updating conversation description" : "Fel uppstod när beskrivningen av konversationen skulle uppdateras",
    "Enter a name for this conversation" : "Ange ett namn för den här konversationen",
    "Edit conversation name" : "Ändra namn på konversation",
    "Edit conversation description" : "Ändra beskrivning på konversation",
    "Enter a description for this conversation" : "Ange en beskrivning för den här konversationen",
    "Picture" : "Bild",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Följande bottar kan aktiveras i den här konversationen. Kontakta din administratör för att få fler bottar installerade på den här servern.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Inga bottar är installerade på denna server. Kontakta din administratör för att få bottar installerade på den här servern.",
    "Disable" : "Inaktivera",
    "Enable" : "Aktivera",
    "The bot is not available anymore" : "Boten är inte längre tillgänglig",
    "Breakout rooms" : "Grupprum",
    "Manage breakout rooms" : "Hantera grupprum",
    "Set up breakout rooms for this conversation" : "Konfigurera grupprum för den här konversationen",
    "Please select a valid PNG or JPG file" : "Välj en giltig PNG- eller JPG-fil",
    "Choose your conversation picture" : "Välj din konversationsbild",
    "Choose" : "Välj",
    "Error setting conversation picture" : "Fel vid inställning av konversationsbild",
    "Could not set the conversation picture: {error}" : "Kunde inte ställa in konversationsbilden: {error}",
    "Error cropping conversation picture" : "Kunde inte beskära konversationsbilden",
    "Error removing conversation picture" : "Kunde inte ta bort konversationsbilden",
    "Set emoji as conversation picture" : "Ställ in emoji som konversationsbild",
    "Set background color for conversation picture" : "Ställ in bakgrundsfärg för konversationsbild",
    "Upload conversation picture" : "Ladda upp konversationsbild",
    "Choose conversation picture from files" : "Välj konversationsbild från filer",
    "Remove conversation picture" : "Ta bort konversationsbild",
    "The file must be a PNG or JPG" : "Filen måste vara en PNG eller JPG",
    "Set picture" : "Ställ in bild",
    "Default permissions modified for {conversationName}" : "Standardbehörigheter har ändrats för {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Kunde inte ändra standardbehörigheter för {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Redigera standardbehörigheterna för deltagare i den här konversationen. Dessa inställningar påverkar inte moderatorer.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Varje gång behörigheter ändras i det här avsnittet kommer anpassade behörigheter som tidigare tilldelats enskilda deltagare att gå förlorade.",
    "All permissions" : "Alla behörigheter",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Deltagare har behörighet att starta ett samtal, gå med i ett samtal, aktivera ljud och video samt dela skärm.",
    "Participants can use all available features." : "Deltagare kan använda alla tillgängliga funktioner.",
    "Restricted" : "Begränsad",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Deltagare kan gå med i samtal, men kan inte aktivera ljud eller video eller dela skärm förrän en moderator manuellt ger dem behörighet.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Deltagare får en begränsad uppsättning funktioner tills en moderator manuellt beviljar ytterligare behörigheter.",
    "Advanced permissions" : "Avancerade behörigheter",
    "Edit permissions" : "Redigera behörigheter",
    "Conversation settings" : "Konversationsinställningar",
    "Basic Info" : "Grundläggande info",
    "Personal" : "Personligt",
    "Moderation" : "Moderering",
    "Setup overview" : "Inställningsöversikt",
    "Live transcription" : "Live-transkribering",
    "Live transcriptions app is not installed" : "Appen Live transcriptions är inte installerad",
    "Enable live transcription" : "Aktivera live-transkribering",
    "Breakout Rooms" : "Grupprum",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bottar",
    "Danger zone" : "Riskzon",
    "Archive conversation" : "Arkivera konversation",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Arkiverade konversationer är dolda från konversationslistan som standard. De kommer dock fortfarande att visas när du söker efter konversationsnamnet eller kommer åt en lista med arkiverade konversationer.",
    "Do you really want to leave \"{displayName}\"?" : "Vill du verkligen lämna \"{displayName}\"?",
    "You can archive this conversation instead." : "Du kan arkivera den här konversationen istället.",
    "Leave conversation" : "Lämna konversationen",
    "You need to promote a new moderator before you can leave the conversation" : "Du måste tilldela en ny moderator innan du kan lämna konversationen",
    "Delete conversation" : "Ta bort konversationen",
    "Do you really want to delete \"{displayName}\"?" : "Vill du verkligen radera \"{displayName}\"?",
    "Error while deleting conversation" : "Kunde inte ta bort konversationen",
    "Delete all chat messages" : "Radera alla chattmeddelanden",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Vill du verkligen radera alla meddelanden i \"{displayName}\"?",
    "Error while clearing chat history" : "Kunde inte rensa chatthistoriken",
    "Be careful, these actions cannot be undone." : "Var försiktig, dessa åtgärder kan inte ångras.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "När en konversation har lämnats krävs en inbjudan för att återgå till en sluten konversation. En öppen konversation kan återanslutas när som helst.",
    "Permanently delete this conversation." : "Radera den här konversationen permanent.",
    "Delete chat messages" : "Radera chattmeddelanden",
    "Permanently delete all the messages in this conversation." : "Radera alla meddelanden i den här konversationen permanent.",
    "Custom expiration time" : "Anpassad utgångstid",
    "Message expiration disabled" : "Utgångstid för meddelanden är inaktiverat",
    "Message expiration set: {duration}" : "Meddelandets utgångstid: {duration}",
    "Error when trying to set message expiration" : "Fel vid försök att ställa in meddelandets utgång",
    "Message expiration" : "Meddelande löper ut",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chattmeddelanden kan löpa ut efter en viss tid. Notera: Filer som delas i chatten kommer inte att raderas för ägaren, men kommer inte längre att delas i konversationen.",
    "Set message expiration" : "Ställ in meddelandes utgångstid",
    "Current message expiration" : "Nuvarande utgångstid för meddelande",
    "Password copied to clipboard" : "Lösenordet har kopierats till urklipp",
    "Password could not be copied" : "Lösenordet kunde inte kopieras",
    "Guest access" : "Gäståtkomst",
    "Breakout rooms are not allowed in public conversations." : "Grupprum är inte tillåtna i publika konversationer.",
    "Allow guests to join this conversation via link" : "Tillåt gäster att gå med i denna konversation via länk",
    "Password protection" : "Lösenordsskydd",
    "This conversation is password-protected. Guests need password to join" : "Den här konversationen är lösenordsskyddad. Gäster behöver lösenord för att gå med",
    "Password protection is needed for public conversations" : "Lösenordsskydd krävs för offentliga konversationer",
    "Set a password" : "Sätt ett lösenord",
    "Change password" : "Byt lösenord",
    "Enter new password" : "Ange nytt lösenord",
    "Save password" : "Spara lösenord",
    "Copy password" : "Kopiera lösenord",
    "Guests are allowed to join this conversation via link" : "Gäster får gå med i denna konversation via länk",
    "Guests are not allowed to join this conversation" : "Gäster får inte gå med i denna konversation",
    "Resend invitations" : "Skicka inbjudningar igen",
    "This conversation is open to both registered users and users created with the Guests app" : "Den här konversationen är öppen för både registrerade användare och användare som skapats med appen Gäster",
    "This conversation is open to registered users" : "Denna konversation är öppen för registrerade användare",
    "This conversation is limited to the current participants" : "Denna konversation är begränsad till de aktuella deltagarna",
    "You opened the conversation to both registered users and users created with the Guests app" : "Du öppnade konversationen för både registrerade användare och användare som skapats med appen Gäster",
    "Error occurred when opening or limiting the conversation" : "Ett fel uppstod när konversationen öppnades eller begränsades",
    "Open conversation to registered users, showing it in search results" : "Öppna konversationen för registrerade användare och visa den i sökresultaten",
    "Also open to users created with the Guests app" : "Även öppen för användare som skapats med appen Gäster",
    "Open conversation" : "Öppen konversation",
    "Set language spoken in calls" : "Ange vilket språk som talas i samtal",
    "Languages could not be loaded" : "Språk kunde inte laddas",
    "Loading languages …" : "Laddar språk …",
    "Invalid language" : "Ogiltigt språk",
    "Default language (English)" : "Standardspråk (engelska)",
    "Default live transcription language set" : "Standardspråk för live-transkribering har angetts",
    "Live transcription language set: {languageName}" : "Språk för live-transkribering inställt: {languageName}",
    "Error when trying to set live transcription language" : "Fel vid försök att ställa in språk för live-transkribering",
    "Start time: {date}" : "Starttid: {date}",
    "Start time has been updated" : "Starttiden har uppdaterats",
    "Error occurred while updating start time" : "Fel uppstod vid uppdatering av starttid",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Aktivering av lobbyn kommer att ta bort icke-moderatorer från det pågående samtalet.",
    "Enable lobby, restricting the conversation to moderators" : "Aktivera lobbyn, begränsa konversationen till moderatorer",
    "Meeting start time" : "Mötets starttid",
    "Start time (optional)" : "Starttid (valfritt)",
    "Import email participants" : "Importera e-postdeltagare",
    "You can import a list of email participants from a CSV file." : "Du kan importera en lista över e-postdeltagare från en CSV-fil.",
    "Poll drafts" : "Omröstningsutkast",
    "Browse poll drafts" : "Bläddra bland omröstningsutkast",
    "Error occurred when locking the conversation" : "Ett fel uppstod när konversationen skulle låsas",
    "Error occurred when unlocking the conversation" : "Ett fel uppstod när konversationen skulle låsas upp",
    "Lock conversation" : "Lås konversation",
    "This will also terminate the ongoing call." : "Detta kommer också att avsluta det pågående samtalet.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Lås konversationen för att förhindra att någon skickar meddelanden eller startar samtal",
    "Edit" : "Ändra",
    "More information" : "Mer information",
    "Delete" : "Radera",
    "Add new bridged channel to current conversation" : "Lägg till ny bryggad kanal till aktuell konversation",
    "unknown state" : "okänt tillstånd",
    "running" : "aktiv",
    "not running, check Matterbridge log" : "inte aktiv, kontrollera Matterbridge-loggen",
    "not running" : "inte aktiv",
    "Bridge saved" : "Brygga sparad",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Du kan brygga kanaler från olika snabbmeddelandesystem med Matterbridge.",
    "More info on Matterbridge" : "Mer information om Matterbridge",
    "Messaging systems" : "Meddelandesystem",
    "Enable bridge" : "Aktivera brygga",
    "Show Matterbridge log" : "Visa Matterbridge-logg",
    "Log content" : "Logginnehåll",
    "Only moderators are allowed to mention @all" : "Endast moderatorer får nämna @all",
    "All participants are allowed to mention @all" : "Alla deltagare får nämna @all",
    "Participants are now allowed to mention @all." : "Deltagarna får nu nämna @all.",
    "Mentioning @all has been limited to moderators." : "Att nämna @all har begränsats till moderatorer.",
    "Allow participants to mention @all" : "Tillåt deltagarna att nämna @all",
    "Mention permissions" : "Behörigheter för omnämnanden",
    "Notifications" : "Aviseringar",
    "Notify about calls in this conversation" : "Meddela om samtal i den här konversationen",
    "Important conversation" : "Viktigt samtal",
    "\"Do not disturb\" user status is ignored for important conversations" : "Användarstatus \"Stör ej\" ignoreras för viktiga konversationer",
    "Sensitive conversation" : "Känslig konversation",
    "Message preview will be disabled in conversation list and notifications" : "Förhandsvisning av meddelanden kommer att inaktiveras i konversationslistan och i aviseringar",
    "Recording consent is required for calls in this conversation" : "Samtycke för inspelning krävs för samtal i denna konversation",
    "Recording consent is not required for calls in this conversation" : "Samtycke för inspelning krävs inte för samtal i denna konversation",
    "Recording consent requirement was updated" : "Kravet på samtycke vid inspelning har uppdaterats",
    "Error occurred while updating recording consent" : "Fel uppstod vid uppdatering av samtycke för inspelning",
    "Recording Consent" : "Samtycke för inspelning",
    "Recording consent cannot be changed once a call or breakout session has started." : "Samtycke för inspelning kan inte ändras när ett samtal eller grupprum har startat.",
    "Require recording consent before joining call in this conversation" : "Kräv inspelningssamtycke för att gå med i samtalet i den här konversationen",
    "Recording consent is required for all calls" : "Samtycke för inspelning krävs för alla samtal",
    "SIP dial-in is now possible without PIN requirement" : "SIP-inringning är nu möjlig utan PIN-krav",
    "SIP dial-in is now enabled" : "SIP-inringning är nu aktiverad",
    "SIP dial-in is now disabled" : "SIP-inringning är nu inaktiverad",
    "Error occurred when enabling SIP dial-in" : "Ett fel uppstod när SIP-inringning skulle aktiveras",
    "Error occurred when disabling SIP dial-in" : "Ett fel uppstod när SIP-inringning skulle inaktiveras",
    "Phone and SIP dial-in" : "Telefon och SIP-inringning",
    "Enable phone and SIP dial-in" : "Aktivera telefon och SIP-inringning",
    "Allow to dial-in without a PIN" : "Tillåt att ringa in utan PIN",
    "Ongoing" : "Pågår",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n person har accepterat","%n personer har accepterat"],
    "_%n person declined_::_%n people declined_" : ["%n person har avböjt","%n personer har avböjt"],
    "_and %n other attachment_::_and %n other attachments_" : ["och %n annan bilaga","och %n andra bilagor"],
    "With {displayName}" : "Med {displayName}",
    "In {conversation}" : "I {conversation}",
    "View attachment" : "Visa bilaga",
    "Join" : "Gå med",
    "View conversation" : "Visa konversation",
    "View event on Calendar" : "Visa händelse i kalender",
    "Error while creating the conversation" : "Fel uppstod när konversationen skulle skapas",
    "Hello, {displayName}" : "Hej, {displayName}",
    "Start meeting now" : "Starta möte nu",
    "Give your meeting a title" : "Ge ditt möte en titel",
    "Create and copy link" : "Skapa och kopiera länk",
    "Create a new conversation" : "Skapa en ny konversation",
    "Join open conversations" : "Gå med i öppna konversationer",
    "Call a phone number" : "Ring ett telefonnummer",
    "Scroll backward" : "Skrolla bakåt",
    "Scroll forward" : "Skrolla framåt",
    "Schedule meetings" : "Schemalägg möten",
    "You don't have any upcoming meetings" : "Du har inga kommande möten",
    "Calendar events with a conversation link as the location are shown here" : "Kalenderhändelser med en konversationslänk som plats visas här",
    "Open calendar" : "Öppna kalender",
    "Unread mentions" : "Olästa omnämnanden",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Meddelanden där du har blivit nämnd visas här. Du kan nämna personer genom att skriva @ följt av deras namn",
    "Upcoming reminders" : "Kommande påminnelser",
    "Message reminders" : "Meddelandepåminnelser",
    "Set a reminder on a message to be notified" : "Ställ in en påminnelse på ett meddelande för att få en avisering",
    "Start a group conversation" : "Skapa en gruppkonversation",
    "Create conversation" : "Skapa konversation",
    "Enter your name" : "Ange ditt namn",
    "Submit name and join" : "Ange namn och gå med",
    "Do you already have an account?" : "Har du redan ett konto?",
    "Log in" : "Logga in",
    "Error while verifying uploaded file" : "Fel vid verifiering av uppladdad fil",
    "Uploaded file is verified" : "Uppladdad fil är verifierad",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Innehållsformatet är kommaseparerade värden (CSV):<br/>- Rubrikrad krävs och måste matcha <samp>\"namn\",\"e-post\"</samp> eller bara <samp>\"e-post\"</samp><br/>- En post per rad (t.ex. <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Deltagare har lagts till",
    "Error while adding participants" : "Det gick inte att lägga till deltagare",
    "Import a file" : "Importera en fil",
    "Browse" : "Bläddra",
    "Verifying uploaded file …" : "Verifierar uppladdad fil …",
    "This might take a moment" : "Det här kan ta ett tag",
    "Send invitations" : "Skicka inbjudningar",
    "_%n invalid email_::_%n invalid emails_" : ["%n ogiltig e-postadress","%n ogiltiga e-postadresser"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-postadress är redan importerade eller en dubblett","%n e-postadresser är redan importerade eller dubbletter"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n inbjudning kan skickas","%n inbjudningar kan skickas"],
    "An error occurred while calling a phone number" : "Ett fel uppstod när ett telefonnummer ringdes",
    "Phone number could not be called: {error}" : "Kunde inte ringa upp telefonnummer: {error}",
    "Phone number could not be called" : "Kunde inte ringa upp telefonnummer",
    "Search participants or phone numbers" : "Sök deltagare eller telefonnummer",
    "Creating the conversation …" : "Skapar konversationen ...",
    "Mark as read" : "Markera som läst",
    "Mark as unread" : "Markera som oläst",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Unarchive conversation" : "Avarkivera konversation",
    "Ignore \"Do not disturb\"" : "Ignorera \"Stör ej\"",
    "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
    "New tag" : "Ny tagg",
    "Tag name" : "Namn på tagg",
    "Conversation actions" : "Konversationsåtgärder",
    "Tags" : "Taggar",
    "Notify about calls" : "Meddela om samtal",
    "Hide message text" : "Göm meddelandetext",
    "Remove all tags" : "Ta bort alla taggar",
    "Rename tag" : "Byt namn på tagg",
    "Delete tag" : "Radera tagg",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "Vill du verkligen ta bort \"{name}\"? Konversationer med denna tagg flyttas till \"Övrigt\".",
    "Move up" : "Flytta upp",
    "Move down" : "Flytta ner",
    "Pending invitations" : "Väntande inbjudningar",
    "Join conversations from other servers" : "Gå med i konversationer från andra servrar",
    "From {user} at {remoteServer}" : "Från {user} på {remoteServer}",
    "Decline invitation" : "Avböj inbjudan",
    "Accept invitation" : "Acceptera inbjudan",
    "No pending invitations" : "Inga väntande inbjudningar",
    "Home" : "Hem",
    "Unread" : "Oläst",
    "Mentions" : "Omnämnanden",
    "Meetings" : "Möten",
    "Sort conversations" : "Sortera konversationer",
    "By recent activity" : "Efter senaste aktivitet",
    "Alphabetically" : "Alfabetisk",
    "Do not group by type" : "Gruppera inte efter typ",
    "Show private ones first" : "Visa privata först",
    "Show group ones first" : "Visa grupper först",
    "No followed threads" : "Inga följda trådar",
    "No matches found" : "Inga träffar hittades",
    "No conversations found" : "Inga konversationer hittades",
    "You have no archived conversations." : "Du har inga arkiverade konversationer.",
    "Subscribe to an existing thread or start your own." : "Prenumerera på en befintlig tråd eller starta en egen.",
    "You have no unread mentions." : "Du har inga olästa omnämnanden.",
    "You have no unread messages." : "Du har inga olästa meddelanden.",
    "An error occurred while performing the search" : "Ett fel uppstod när sökningen utfördes",
    "Conversation list" : "Konversationslista",
    "Filter conversations by" : "Filtrera konversationer efter",
    "Unread messages" : "Olästa meddelanden",
    "Meeting conversations" : "Möteskonversationer",
    "Clear filters" : "Rensa filter",
    "New personal note" : "Ny personlig anteckning",
    "SIP backend is not installed" : "SIP-backend är inte installerad",
    "Back to conversations" : "Tillbaka till konversationer",
    "Threads" : "Trådar",
    "Archived conversations" : "Arkiverade konversationer",
    "Clear filter" : "Rensa filter",
    "Show more threads" : "Visa fler trådar",
    "App settings" : "Appinställningar",
    "Users" : "Användare",
    "Groups" : "Grupper",
    "Teams" : "Teams",
    "Federated users" : "Federerade användare",
    "New private conversation" : "Ny privat konversation",
    "Other sources" : "Andra källor",
    "Open conversations" : "Öppna konversationer",
    "No search results" : "Inga sökresultat",
    "Users, groups and teams" : "Användare, grupper och team",
    "Users and groups" : "Användare och grupper",
    "Users and teams" : "Användare och team",
    "Groups and teams" : "Grupper och team",
    "New group conversation" : "Ny gruppkonversation",
    "The meeting will start soon" : "Mötet börjar snart",
    "This meeting is scheduled for {startTime}" : "Det här mötet är planerat till {startTime}",
    "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
    "Enable noise suppression" : "Aktivera brusreducering",
    "Reduce background noises for better voice quality" : "Minska bakgrundsljud för bättre ljudkvalitet",
    "Basic" : "Grundläggande",
    "Advanced" : "Avancerad",
    "Enable echo cancellation" : "Aktivera ekoborttagning",
    "Minimize echo effect from own surrounding" : "Minimera eko från din omgivning",
    "Enable auto gain control" : "Aktivera automatisk ljudnivåjustering",
    "Dynamically adjust microphone volume for consistent level" : "Justera mikrofonvolymen dynamiskt för en jämn nivå",
    "Select microphone" : "Välj mikrofon",
    "No microphone available" : "Ingen mikrofon tillgänglig",
    "Select speaker" : "Välj högtalare",
    "No speaker available" : "Ingen högtalare tillgänglig",
    "Select camera" : "Välj kamera",
    "No camera available" : "Ingen kamera tillgänglig",
    "Select a device" : "Välj en enhet",
    "Playing …" : "Spelar …",
    "Test speakers" : "Testa högtalare",
    "Test" : "Test",
    "Devices" : "Enheter",
    "Backgrounds" : "Bakgrunder",
    "No audio" : "Inget ljud",
    "No camera" : "Ingen kamera",
    "Display video as you will see it (mirrored)" : "Visa video som du kommer att se den (speglad)",
    "Display video as others will see it" : "Visa video som andra kommer att se den",
    "Calls are not supported in your browser" : "Samtal stöds inte i din webbläsare",
    "Access to microphone is only possible with HTTPS" : "Åtkomst till mikrofon är endast möjligt via HTTPS",
    "Access to microphone was denied" : "Åtkomst till mikrofon nekades",
    "Error while accessing microphone" : "Fel vid åtkomst till mikrofon",
    "Access to camera is only possible with HTTPS" : "Åtkomst till kamera är endast möjligt via HTTPS",
    "The call is being recorded." : "Samtalet spelas in.",
    "The call might be recorded." : "Samtalet kan spelas in.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Inspelningen kan innehålla din röst, video från kameran och skärmdelning. Ditt samtycke krävs innan du går med i samtalet.",
    "Give consent to the recording of this call" : "Ge samtycke till inspelningen av detta samtal",
    "Show more info" : "Visa mer information",
    "Audio is not available" : "Ljud är inte tillgängligt",
    "Video is not available" : "Video är inte tillgänglig",
    "Start recording immediately with the call" : "Börja spela in omedelbart med samtalet",
    "Recording backend is not installed" : "Recording-backend är inte installerad",
    "Notify all participants about this call" : "Meddela alla deltagare om detta samtal",
    "Apply settings" : "Tillämpa inställningar",
    "Select virtual office background" : "Välj bakgrund för virtuell kontor",
    "Select virtual home background" : "Välj bakgrund för virtuellt hem",
    "Select virtual abstract background" : "Välj virtuell abstrakt bakgrund",
    "Select virtual beach background" : "Välj virtuell strandbakgrund",
    "Select virtual park background" : "Välj virtuell parkbakgrund",
    "Select virtual theater background" : "Välj virtuell teaterbakgrund",
    "Select virtual library background" : "Välj bakgrund för virtuellt bibliotek",
    "Select virtual space station background" : "Välj bakgrund för virtuell rymdstation",
    "Error while uploading the file" : "Fel vid uppladdning av fil",
    "Select a file" : "Välj en fil",
    "Invalid path selected" : "Ogiltig sökväg vald",
    "Select virtual background from file {fileName}" : "Välj virtuell bakgrund från fil {fileName}",
    "Blur" : "Suddig",
    "Upload" : "Ladda upp",
    "Files" : "Filer",
    "(editing)" : "(redigerar)",
    "(edited)" : "(redigerad)",
    "The message has expired or has been deleted" : "Meddelandet har löpt ut eller raderats",
    "Cancel quote" : "Avbryt citat",
    "24 hours" : "24 timmar",
    "7 days" : "7 dagar",
    "30 days" : "30 dagar",
    "Until unpin" : "Tills fästet tas bort",
    "Clear reminder – {timeLocale}" : "Rensa påminnelse – {timeLocale}",
    "Edited by {actor}" : "Redigerad av {actor}",
    "Pinned by you" : "Fäst av dig",
    "Pinned by {actor}" : "Fäst av {actor}",
    "Until {absoluteDate}" : "Till {absoluteDate}",
    "Message text copied to clipboard" : "Meddelandetext har kopierats till urklipp",
    "Message text could not be copied" : "Kunde inte kopiera meddelandetexten",
    "Message forwarded to \"Note to self\"" : "Meddelande vidarebefordrat till \"Egna anteckningar\"",
    "Error while forwarding message to \"Note to self\"" : "Fel vid vidarebefordran av meddelande till \"Egna anteckningar\"",
    "A reminder was successfully removed" : "En påminnelse har tagits bort",
    "Error occurred when removing a reminder" : "Ett fel uppstod när en påminnelse skulle tas bort",
    "A reminder was successfully set at {datetime}" : "En påminnelse har ställts in {datetime}",
    "Error occurred when creating a reminder" : "Ett fel uppstod när en påminnelse skapades",
    "Add a reaction to this message" : "Lägg till en reaktion till detta meddelande",
    "Reply" : "Svara",
    "More actions" : "Fler händelser",
    "Set reminder" : "Ställ in påminnelse",
    "Pin message" : "Fäst meddelande",
    "Unpin message" : "Ta bort fäst meddelande",
    "Reply privately" : "Svara privat",
    "Edit message" : "Redigera meddelande",
    "Copy message" : "Kopiera meddelande",
    "Copy message link" : "Kopiera meddelandelänk",
    "Go to file" : "Gå till fil",
    "Download file" : "Ladda ner fil",
    "Go to thread" : "Gå till tråd",
    "Edit thread details" : "Redigera tråddetaljer",
    "Forward message" : "Vidarebefordra meddelande",
    "Translate" : "Översätt",
    "Set custom reminder" : "Ställ in anpassad påminnelse",
    "Keep pinned for" : "Behåll fäst i",
    "Set custom period" : "Ange anpassad period",
    "Close reactions menu" : "Stäng reaktionsmenyn",
    "React with {emoji}" : "Reagera med {emoji}",
    "React with another emoji" : "Reagera med en annan emoji",
    "Choose a conversation to forward the selected message." : "Välj en konversation för att vidarebefordra det valda meddelandet.",
    "Error while forwarding message" : "Fel vid vidarebefordran av meddelande",
    "The message has been forwarded to {selectedConversationName}" : "Meddelandet har vidarebefordrats till {selectedConversationName}",
    "Dismiss" : "Avfärda",
    "Go to conversation" : "Gå till konversation",
    "Detect language" : "Upptäck språk",
    "The message could not be translated" : "Meddelandet kunde inte översättas",
    "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
    "Translation could not be copied" : "Översättningen kunde inte kopieras",
    "Translate message" : "Översätt meddelande",
    "Source language to translate from" : "Språk att översätta från",
    "Translate from" : "Översätt från",
    "Target language to translate into" : "Språk att översätta till",
    "Translate to" : "Översätt till",
    "Translating" : "Översätter",
    "This translation is AI generated and may contain mistakes." : "Denna översättning är AI-genererad och kan innehålla fel.",
    "Copy translated text" : "Kopiera översatt text",
    "Error when scheduling the message" : "Kunde inte schemalägga meddelandet",
    "Reschedule" : "Ändra schemaläggning",
    "Send now" : "Skicka nu",
    "Choose a time" : "Välj en tid",
    "Send at custom time" : "Skicka vid anpassad tid",
    "Will be sent without notification" : "Kommer att skickas utan avisering",
    "Message read by everyone who shares their reading status" : "Meddelandet läst av alla som delar sin lässtatus",
    "Message sent" : "Meddelande skickat",
    "Sent without notification" : "Skickat utan avisering",
    "Deleting message" : "Raderar meddelande",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Meddelandet har raderats, men en bott eller Matterbridge är konfigurerat och meddelandet kanske redan har distribuerats till andra tjänster",
    "Message deleted successfully" : "Meddelandet har raderats",
    "Message could not be deleted because it is too old" : "Meddelandet kunde inte raderas eftersom det är för gammalt",
    "Only normal chat messages can be deleted" : "Endast normala chattmeddelanden kan raderas",
    "An error occurred while deleting the message" : "Ett fel uppstod när meddelandet skulle raderas",
    "Pinned" : "Fäst",
    "Your browser does not support playing audio files" : "Din webbläsare stöder inte uppspelning av ljudfiler",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} i {board}",
    "Deck Card" : "Deck-kort",
    "Remove {fileName}" : "Ta bort {fileName}",
    "Open this location in OpenStreetMap" : "Öppna denna plats i OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n svar","%n svar"],
    "Sending message" : "Skickar meddelande",
    "Failed to send the message. Click to try again" : "Kunde inte skicka meddelandet. Klicka för att försöka igen",
    "Not enough free space to upload file" : "Inte tillräckligt med ledigt utrymme för att ladda upp filen",
    "You cannot send messages to this conversation at the moment" : "Du kan inte skicka meddelanden till den här konversationen för tillfället",
    "Could not update the message" : "Kunde inte uppdatera meddelandet",
    "Reply to thread \"{threadTitle}\"" : "Svara i tråd \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Du röstade • %n röst","Du röstade • %n röster"],
    "You voted" : "Du röstade",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Klicka för att rösta • %n röst","Klicka för att rösta • %n röster"],
    "Click to vote" : "Klicka för att rösta",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Omröstningsutkast • %n alternativ","Omröstningsutkast • %n alternativ"],
    "_%n vote_::_%n votes_" : ["%n röst","%n röster"],
    "Edit poll draft" : "Redigera omröstningsutkast",
    "Delete poll draft" : "Ta bort utkast till omröstning",
    "Open poll" : "Öppna omröstning",
    "Closed poll" : "Avslutad omröstning",
    "See results" : "Se resultat",
    "Reactions" : "Reaktioner",
    "No permission to post reactions in this conversation" : "Ingen behörighet att posta reaktioner i denna konversation",
    "and {participant}" : "och {participant}",
    "_and %n other participant_::_and %n other participants_" : ["och %n annan deltagare","och %n andra deltagare"],
    "Show all reactions" : "Visa alla reaktioner",
    "Add more reactions" : "Lägg till fler reaktioner",
    "Show or collapse system messages" : "Visa eller dölj systemmeddelanden",
    "No messages" : "Inga meddelanden",
    "All messages have expired or have been deleted." : "Alla meddelanden har löpt ut eller har raderats.",
    "Generate summary with AI" : "Skapa en sammanfattning med AI",
    "{author} (pinned by you)" : "{author} (fäst av dig)",
    "{author} (pinned by {actor})" : "{author} (fäst av {actor})",
    "Unpin" : "Lossa",
    "Cancel search" : "Avbryt sökning",
    "Add a phone number" : "Lägg till ett telefonnummer",
    "Error: A password is required to create the conversation." : "Fel: Ett lösenord krävs för att skapa konversationen.",
    "All set, the conversation \"{conversationName}\" was created." : "Allt klart, konversationen \"{conversationName}\" skapades.",
    "Create a new group conversation" : "Skapa en ny gruppkonversation",
    "Add participants" : "Lägg till deltagare",
    "Maximum length exceeded ({maxlength} characters)" : "Maximal längd har överskridits ({maxlength} tecken)",
    "Conversation type" : "Konversationstyp",
    "Default parameters are:" : "Standardparametrar är:",
    "These settings can be changed once the conversation is created." : "Dessa inställningar kan ändras när konversationen har skapats.",
    "Conversation visibility" : "Konversationens synlighet",
    "Allow guests to join via link" : "Tillåt gäster att ansluta via länk",
    "Enter password" : "Ange lösenord",
    "This conversation has been locked" : "Den här konversationen har låsts",
    "No permission to post messages in this conversation" : "Ingen behörighet att skicka meddelanden i den här konversationen",
    "Joining conversation …" : "Går med i konversationen ...",
    "Write a message without notification" : "Skriv ett meddelande utan avisering",
    "Create a thread silently" : "Skapa en tråd utan avisering",
    "Create a thread" : "Skapa en tråd",
    "Send message silently" : "Skicka meddelande tyst",
    "Send message" : "Skicka meddelande",
    "Send without notification" : "Skicka utan avisering",
    "The participant will not be notified about new messages" : "Deltagaren kommer inte att meddelas om nya meddelanden",
    "Participants will not be notified about new messages" : "Deltagare kommer inte att meddelas om nya meddelanden",
    "Message will be sent {datetimeString}" : "Meddelandet kommer att skickas {datetimeString}",
    "Thread title is required" : "Trådtitel krävs",
    "Message text is required" : "Meddelandetext krävs",
    "The message could not be edited" : "Meddelandet kunde inte redigeras",
    "File to share" : "Fil att dela",
    "File upload is not available in this conversation" : "Filuppladdning är inte tillgängligt i den här konversationen",
    "Message was successfully scheduled" : "Meddelandet har schemalagts",
    "Add emoji" : "Lägg till emoji",
    "Adding a mention will only notify users who did not read the message." : "Om du lägger till ett omnämnande kommer endast användare som inte har läst meddelandet att meddelas.",
    "Thread title" : "Trådtitel",
    "Send later" : "Skicka senare",
    "Show scheduled messages" : "Visa schemalagda meddelanden",
    "Cancel editing" : "Avbryt redigering",
    "Schedule message" : "Schemalägg meddelande",
    "{user} is out of office and might not respond." : "{user} är frånvarande och kanske inte svarar.",
    "Absence period: {startDate} - {endDate}" : "Frånvaroperiod: {startDate} - {endDate}",
    "Replacement:" : "Ersättning:",
    "Share from {nextcloud}" : "Dela från {nextcloud}",
    "Share from Files" : "Dela från Filer",
    "Share files to the conversation" : "Dela filer till konversationen",
    "Upload from device" : "Ladda upp från enheten",
    "Create new poll" : "Skapa ny omröstning",
    "Smart picker" : "Smart picker",
    "Record voice message" : "Spela in röstmeddelande",
    "End recording and send" : "Avsluta inspelningen och skicka",
    "Dismiss recording" : "Stäng inspelningen",
    "Access to the microphone was denied" : "Åtkomst till mikrofon nekades",
    "Microphone either not available or disabled in settings" : "Mikrofonen är antingen inte tillgänglig eller inaktiverad i inställningarna",
    "Error while recording audio" : "Fel vid inspelning av ljud",
    "Voice message {time} ({conversation})" : "Röstmeddelande {time} ({conversation})",
    "Generating summary of unread messages …" : "Skapar sammanfattning av olästa meddelanden ...",
    "Summary is AI generated and might contain mistakes" : "Sammanfattningen är AI-genererad och kan innehålla misstag",
    "Error occurred during a summary generation" : "Ett fel uppstod vid generering av sammanfattning",
    "New file" : "Ny fil",
    "Blank" : "Tom",
    "Error while creating file" : "Fel när filen skapades",
    "Create and share a new file" : "Skapa och dela en ny fil",
    "Name of the new file" : "Namn på den nya filen",
    "Create file" : "Skapa fil",
    "Someone is typing …" : "Någon skriver …",
    "{user1} is typing …" : "{user1} skriver …",
    "{user1} and {user2} are typing …" : "{user1} och {user2} skriver …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} och {user3} skriver …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} och %n annan skriver …","{user1}, {user2}, {user3} och %n andra skriver …"],
    "Add more files" : "Lägg till fler filer",
    "Send" : "Skicka",
    "In this conversation <strong>{user}</strong> can:" : "I denna konversation <strong>{user}</strong> kan:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Redigera standardbehörigheter för deltagare i <strong>{conversationName}</strong>",
    "Start a call" : "Starta samtal",
    "Skip the lobby" : "Hoppa över lobbyn",
    "Can post messages" : "Kan skicka meddelanden",
    "Can post messages and reactions" : "Kan posta meddelanden och reaktioner",
    "Can add reactions" : "Kan lägga till reaktioner",
    "Enable the microphone" : "Aktivera mikrofon",
    "Enable the camera" : "Aktivera kameran",
    "Share the screen" : "Dela skärmen",
    "Update permissions" : "Uppdatera behörigheter",
    "Updating permissions" : "Uppdaterar behörigheter",
    "No poll drafts" : "Inga omröstningsutkast",
    "There is no poll drafts yet saved for this conversation" : "Det finns inga omröstningsutkast ännu sparade för den här konversationen",
    "Create poll in {name}" : "Skapa omröstning i {name}",
    "Create poll" : "Skapa omröstning",
    "Error while importing poll" : "Fel vid import av omröstning",
    "Question" : "Fråga",
    "Ask a question" : "Ställ en fråga",
    "Import draft from file" : "Importera utkast från fil",
    "Answers" : "Svar",
    "Answer {option}" : "Svar {option}",
    "Delete poll option" : "Ta bort röstningsalternativ",
    "Add answer" : "Lägg till svar",
    "Settings" : "Inställningar",
    "Anonymous poll" : "Anonym omröstning",
    "Multiple answers" : "Flera svar",
    "Save as draft" : "Spara som utkast",
    "Export draft to file" : "Exportera utkast till fil",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Slutresultat • %n röst","Slutresultat • %n röster"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n röst • Din röst är anonym","%n röster • Din röst är anonym"],
    "Your vote is anonymous" : "Din röst är anonym",
    "You voted for this option" : "Du röstade för det här alternativet",
    "End poll" : "Avsluta omröstning",
    "Change your vote" : "Ändra din röst",
    "Withdraw vote" : "Återkalla röst",
    "Results" : "Resultat",
    "Download as spreadsheet" : "Ladda ned som kalkylblad",
    "Download as CSV" : "Ladda ned som CSV",
    "Voted participants" : "Röstande deltagare",
    "Send a message to \"{roomName}\"" : "Skicka ett meddelande till \"{roomName}\"",
    "Hide list of participants" : "Dölj deltagarlistan",
    "Show list of participants" : "Visa deltagarlista",
    "Assistance requested in {roomName}" : "Hjälp efterfrågas i {roomName}",
    "The message was sent to \"{roomName}\"" : "Meddelandet skickades till \"{roomName}\"",
    "Dismiss request for assistance" : "Avvisa begäran om hjälp",
    "Send message to room" : "Skicka meddelande till rum",
    "Back to main room" : "Tillbaka till huvudrum",
    "Back to your room" : "Tillbaka till ditt rum",
    "Message all rooms" : "Meddelande till alla rum",
    "Start session" : "Starta sessionen",
    "Start a call before you start a breakout room session" : "Starta ett samtal innan du startar grupprum",
    "Stop session" : "Stoppa sessionen",
    "The message was sent to all breakout rooms" : "Meddelandet skickades till alla grupprum",
    "Send a message to all breakout rooms" : "Skicka ett meddelande till alla grupprum",
    "Breakout rooms are not started" : "Grupprum är inte startade",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Samtal utan High-performance backend kan orsaka anslutningsproblem och hög belastning på enheter. {linkstart}Läs mer{linkend}",
    "Talk setup incomplete" : "Talk-installationen är inte klar",
    "Disable lobby" : "Inaktivera lobbyn",
    "Settings for participant \"{user}\"" : "Inställningar för deltagare \"{user}\"",
    "Participant \"{user}\"" : "Deltagare \"{user}\"",
    "moderator" : "moderator",
    "bot" : "bott",
    "guest" : "gäst",
    "Ringing …" : "Ringer …",
    "Call rejected" : "Samtal avvisades",
    "{time} talking …" : "{time} pratar …",
    "{time} talking time" : "{time} samtalstid",
    "Raised their hand" : "Räckte upp handen",
    "Joined with video" : "Anslöt med video",
    "Joined via phone" : "Anslöt via telefon",
    "Joined with audio" : "Anslöt med ljud",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Texten måste vara mindre än eller lika med {maxLength} tecken lång. Din text är {charactersCount} tecken lång.",
    "Remove group and members" : "Ta bort grupp och medlemmar",
    "Remove team and members" : "Ta bort team och medlemmar",
    "Remove participant" : "Ta bort deltagare",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Vill du verkligen ta bort gruppen \"{displayName}\" och dess medlemmar från denna konversation?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Vill du verkligen ta bort team \"{displayName}\" och dess medlemmar från denna konversation?",
    "Do you really want to remove {displayName} from this conversation?" : "Vill du verkligen ta bort {displayName} från denna konversation?",
    "Notification was sent to {displayName}" : "Notifiering skickades till {displayName}",
    "Could not send notification to {displayName}" : "Kunde inte skicka notifiering till {displayName}",
    "Permissions granted to {displayName}" : "Behörighet beviljad till {displayName}",
    "Could not modify permissions for {displayName}" : "Kunde inte ändra behörigheter för {displayName}",
    "Permissions removed for {displayName}" : "Behörigheter har tagits bort för {displayName}",
    "Permissions set to default for {displayName}" : "Behörigheter inställda på standard för {displayName}",
    "Phone number could not be hung up" : "Det gick inte att lägga på telefonnumret",
    "Phone number could not be put on hold" : "Telefonnumret kunde inte parkeras",
    "Phone number could not be muted" : "Telefonnumret kunde inte tystas",
    "Phone number could not be unmuted" : "Kunde inte aktivera ljudet för telefonnummer",
    "DTMF message could not be sent" : "DTMF-meddelande kunde inte skickas",
    "Phone number copied to clipboard" : "Telefonnumret har kopierats till urklipp",
    "Phone number could not be copied" : "Telefonnumret kunde inte kopieras",
    "in the lobby" : "i lobbyn",
    "Dial out phone" : "Telefon för att ringa ut",
    "Hang up phone" : "Lägg på telefon",
    "Move back to lobby" : "Gå tillbaka till lobbyn",
    "Move to conversation" : "Flytta till konversation",
    "Dial-in PIN" : "PIN-kod för uppringning",
    "Demote from moderator" : "Degradera från moderator",
    "Promote to moderator" : "Befordra till moderator",
    "Resend invitation" : "Skicka inbjudning igen",
    "Send call notification" : "Skicka samtalsavisering",
    "Dial out phone number" : "Telefonnummer för att ringa ut",
    "Resume call for phone number" : "Återuppta samtal för telefonnummer",
    "Put phone number on hold" : "Parkera telefonnummer",
    "Unmute phone number" : "Aktivera ljud för telefonnummer",
    "Mute phone number" : "Tysta telefonnummer",
    "Copy phone number" : "Kopiera telefonnummer",
    "Reset custom permissions" : "Återställ anpassade behörigheter",
    "Grant all permissions" : "Tilldela alla behörigheter",
    "Remove all permissions" : "Ta bort alla behörigheter",
    "Also ban from this conversation" : "Blockera även från denna konversation",
    "Internal note (reason to ban)" : "Intern anteckning (anledning till blockering)",
    "Remove" : "Ta bort",
    "Permissions modified for {displayName}" : "Behörigheter har ändrats för {displayName}",
    "Add users, groups or teams" : "Lägg till användare, grupper eller team",
    "Add users or groups" : "Lägg till användare eller grupper",
    "Add users or teams" : "Lägg till användare eller team",
    "Add users" : "Lägg till användare",
    "Add groups or teams" : "Lägg till grupper eller team",
    "Add groups" : "Lägg till grupper",
    "Add teams" : "Lägg till team",
    "Add other sources" : "Lägg till andra källor",
    "Add emails" : "Lägg till e-post",
    "Integrations" : "Integrationer",
    "Add federated users" : "Lägg till federerade användare",
    "Searching …" : "Söker ...",
    "Search for more users" : "Sök efter fler användare",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Du kan söka eller lägga till deltagare via namn, e-post eller federerat Moln-ID",
    "Search or add participants" : "Sök eller lägg till deltagare",
    "Invitation was sent to {actorId}" : "Inbjudan har skickats till {actorId}",
    "An error occurred while adding the participants" : "Ett fel uppstod när deltagarna skulle läggas till",
    "A new group conversation with selected participant will be created" : "En ny gruppkonversation med vald deltagare kommer att skapas",
    "Participants" : "Deltagare",
    "Pinned by a deleted user" : "Fäst av en borttagen användare",
    "Participants ({count})" : "Deltagare ({count})",
    "Open chat" : "Öppna chatt",
    "You have new unread messages in the chat." : "Du har nya olästa meddelanden i chatten.",
    "You have been mentioned in the chat." : "Du har blivit omnämnd i chatten.",
    "Search messages" : "Sök meddelanden",
    "Chat" : "Chatt",
    "Details" : "Detaljer",
    "Shared items" : "Delade objekt",
    "Search in {name}" : "Sök i {name}",
    "Threads in {name}" : "Trådar i {name}",
    "{actor} in {conversation}" : "{actor} i {conversation}",
    "Search messages …" : "Sök meddelanden …",
    "Search options" : "Sökalternativ",
    "From User" : "Från användare",
    "Since" : "Sedan",
    "Until" : "Till",
    "No results found" : "Inga resultat funna",
    "Load more results" : "Visa fler resultat",
    "Recent threads" : "Senaste trådar",
    "Projects" : "Projekt",
    "No shared items" : "Inga delade objekt",
    "Thread notifications" : "Trådaviseringar",
    "Thread actions" : "Trådåtgärder",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Länka till en konversation",
    "No open conversations found" : "Inga öppna konversationer hittades",
    "Either there are no open conversations or you joined all of them." : "Antingen finns det inga öppna konversationer eller så gick du med i alla.",
    "Check spelling or use complete words." : "Kontrollera stavningen eller använd fullständiga ord.",
    "Search conversations or users" : "Sök konversationer eller användare",
    "Select conversation" : "Välj konversation",
    "Number length is not valid" : "Sifferlängden är inte giltig",
    "Region code is not valid" : "Regionkoden är ogiltig",
    "Number length is too short" : "Sifferlängden är för kort",
    "Number length is too long" : "Sifferlängden är för lång",
    "Number is not valid" : "Numret är inte giltigt",
    "Phone numbers" : "Telefonnummer",
    "Display name: {name}" : "Visningsnamn: {name}",
    "Edit display name" : "Ändra visningsnamn",
    "Display name (required)" : "Visningsnamn (obligatoriskt)",
    "Save name" : "Spara namn",
    "I picked message bubbles" : "Jag valde meddelandebubblor",
    "I picked the list style" : "Jag valde listvy",
    "Error while setting personal setting" : "Fel vid inställning av personlig inställning",
    "Error while saving sounds setting" : "Fel när ljudinställningen skulle sparas",
    "Compact conversations list" : "Kompakt konversationslista",
    "Chat appearance" : "Chattutseende",
    "Messages list" : "Meddelandelista",
    "Message bubbles" : "Meddelandebubblor",
    "Play sounds when participants join or leave a call" : "Spela upp ljud när deltagare går med eller lämnar ett samtal",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "För närvarande inte tillgängligt på iPhone och iPad på grund av tekniska begränsningar från tillverkaren",
    "Notification settings" : "Aviseringsinställningar",
    "Sounds for chat and call notifications" : "Ljud för chatt och samtalsaviseringar",
    "Invalid language ({languageId})" : "Ogiltigt språk ({languageId})",
    "Default language" : "Standardspråk",
    "Default language ({languageName})" : "Standardspråk ({languageName})",
    "Error when trying to load the available live translation languages" : "Fel vid försök att läsa in tillgängliga språk för live-översättning",
    "Error when trying to set live translation language" : "Fel vid försök att ställa in språk för live-översättning",
    "Set language used to show the transcriptions" : "Ange språk för visning av transkriberingar",
    "Select location for attachments" : "Välj plats för bilagor",
    "Error while setting attachment folder" : "Fel vid inställning av mapp för bilagor",
    "Error while setting read status privacy" : "Fel vid inställning av sekretess för lässtatus",
    "Error while setting typing status privacy" : "Fel vid inställning av sekretess för skrivstatus",
    "Error while setting default media state" : "Fel vid inställning av standard för mediastatus",
    "Turn camera and microphone off by default" : "Stäng av kamera och mikrofon som standard",
    "Blur camera background by default" : "Gör kamerabakgrunden suddig som standard",
    "Skip device preview before joining a call" : "Hoppa över enhetsförhandsvisning innan du går med i ett samtal",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Kameran stängs av vid anslutning. Visas alltid om samtycke till inspelning krävs.",
    "Appearance & Sounds" : "Utseende och ljud",
    "Privacy" : "Integritet",
    "Send read receipts" : "Skicka läskvitton",
    "When off, all read statuses will be hidden" : "När avstängd döljs alla lässtatusar",
    "Share typing status" : "Dela skrivstatus",
    "When off, all typing indicators will be hidden" : "När avstängd döljs alla skrivindikatorer",
    "Attachments folder" : "Mapp för bilagor",
    "Toggle full screen" : "Växla fullskärm",
    "Return to Home screen" : "Återgå till hemskärmen",
    "Search" : "Sök",
    "Shortcuts while in a chat" : "Genvägar i en chatt",
    "Focus the chat input" : "Fokusera på chattinmatningen",
    "Unfocus the chat input to use shortcuts" : "Avfokusera chattinmatningen för att använda genvägar",
    "Edit your last message" : "Redigera ditt senaste meddelande",
    "Shortcuts while in a call" : "Genvägar under ett samtal",
    "Camera on and off" : "Kamera på och av",
    "Microphone on and off" : "Mikrofon på och av",
    "Raise or lower hand" : "Räck upp eller ta ner handen",
    "Push to talk or push to mute" : "Tryck för att prata eller tryck för att tysta",
    "Zoom-in / zoom-out a screen share" : "Zooma in / zooma ut en skärmdelning",
    "Mouse wheel" : "Mushjul",
    "Start call silently" : "Starta samtal tyst",
    "Start call" : "Starta samtal",
    "End call" : "Avsluta samtal",
    "The server was updated, you cannot start or join a call." : "Servern har uppdaterats, du kan inte starta eller gå med i ett samtal.",
    "This call has just ended" : "Detta samtal har just avslutats",
    "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
    "End call for everyone" : "Avsluta samtal för alla",
    "Starting the recording" : "Starta inspelningen",
    "Recording" : "Inspelning",
    "The call has been running for one hour." : "Samtalet har pågått i en timme.",
    "Cancel recording start" : "Avbryt start av inspelning",
    "Stop recording" : "Stoppa inspelning",
    "Raise hand" : "Räck upp handen",
    "Raise hand (R)" : "Räck upp handen (R)",
    "Lower hand" : "Ta ner handen",
    "Lower hand (R)" : "Ta ner handen (R)",
    "Send a reaction" : "Skicka en reaktion",
    "React with {reaction}" : "Reagera med {reaction}",
    "All tasks done!" : "Alla uppgifter är klara!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} av %n uppgift","{done} av %n uppgifter"],
    "Add participants to this call" : "Lägg till deltagare i det här samtalet",
    "_%n participant in call_::_%n participants in call_" : ["%n deltagare i samtalet","%n deltagare i samtalet"],
    "Scheduled messages" : "Schemalagda meddelanden",
    "You are not allowed to enable screensharing" : "Du får inte aktivera skärmdelning",
    "No screensharing" : "Ingen skärmdelning",
    "Screensharing options" : "Skärmdelningsalternativ",
    "Enable screensharing" : "Tillåt skärmdelning",
    "Bad sent video and screen quality." : "Dålig skickad video och skärmkvalitet.",
    "Bad sent screen quality." : "Dålig skickad skärmkvalitet.",
    "Bad sent video quality." : "Dålig skickad videokvalitet.",
    "Bad sent audio, video and screen quality." : "Dålig skickad ljud-, video- och skärmkvalitet.",
    "Bad sent audio and screen quality." : "Dålig skickat ljud och skärmkvalitet.",
    "Bad sent audio and video quality." : "Dålig skickad ljud- och videokvalitet.",
    "Bad sent audio quality." : "Dålig skickad ljudkvalitet.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan se din skärm. För att förbättra situationen försök att inaktivera suddig bakgrund eller din kamera medan du gör en skärmdelning.",
    "Disable background blur" : "Inaktivera suddig bakgrund",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan se din skärm. För att förbättra situationen försök att inaktivera din kamera medan du gör en skärmdelning.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan se din skärm.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan se dig.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan förstå eller se dig. För att förbättra situationen försök att inaktivera suddig bakgrund eller din kamera medan du gör en skärmdelning.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan förstå eller se dig. För att förbättra situationen försök att inaktivera din kamera medan du gör en skärmdelning.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan förstå dig och se din skärm. För att förbättra situationen försök att inaktivera din skärmdelning.",
    "Disable screenshare" : "Inaktivera skärmdelning",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan förstå eller se dig. För att förbättra situationen försök att inaktivera suddig bakgrund eller din kamera.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan förstå eller se dig. För att förbättra situationen försök att inaktivera din kamera.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Din internetanslutning eller dator är upptagen och andra deltagare kanske inte kan förstå dig.",
    "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
    "Select virtual background" : "Välj virtuell bakgrund",
    "Show your screen" : "Visa din skärm",
    "Stop screensharing" : "Stoppa skärmdelning",
    "Mute others" : "Tysta andra",
    "Start recording" : "Starta inspelning",
    "Set up breakout rooms" : "Ställ in grupprum",
    "Download attendance list" : "Ladda ner deltagarlista",
    "Open Calendar" : "Öppna kalender",
    "Remove participant {name}" : "Ta bort deltagare {name}",
    "Would you like to delete this conversation?" : "Vill du ta bort den här konversationen?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Den här konversationen kommer automatiskt att tas bort för alla efter %n dag utan aktivitet.","Den här konversationen kommer automatiskt att tas bort för alla efter %n dagar utan aktivitet."],
    "Are you sure you want to delete this conversation?" : "Är du säker på att du vill ta bort den här konversationen?",
    "Delete now" : "Ta bort nu",
    "Keep" : "Behåll",
    "Open dialpad" : "Öppna knappsatsen",
    "Select a region" : "Välj en region",
    "Local time: {time}" : "Lokal tid: {time}",
    "Scheduled {datetime}" : "Schemalagd {datetime}",
    "Scheduled for {datetime}" : "Schemalagd till {datetime}",
    "Search …" : "Sök ...",
    "Message without mention" : "Meddelande utan omnämnande",
    "Mention myself" : "Nämn mig själv",
    "Mention everyone" : "Nämn alla",
    "Select a conversation" : "Välj en konversation",
    "Select a mode" : "Välj ett läge",
    "You do not have permissions to access this conversation." : "Du har inte behörighet att komma åt den här konversationen.",
    "Join a different conversation or start a new one." : "Gå med i en annan konversation eller starta en ny.",
    "The conversation does not exist" : "Konversationen finns inte",
    "Join a conversation or start a new one!" : "Anslut till en konversation eller starta en ny!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Den här konversationen har öppnats i en annan flik. Den aktuella serverversionen stöder inte att öppna en konversation i flera flikar.",
    "Creating and joining a conversation with \"{userid}\"" : "Skapar och går med i en konversation med \"{userid}\"",
    "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
    "Error while joining the conversation" : "Kunde inte gå med i konversationen",
    "Another user" : "En annan användare",
    "Hey! Are you using the list style or message bubbles?" : "Hej! Använder du listvy eller meddelandebubblor?",
    "Nextcloud URL" : "Nextcloud-URL",
    "Nextcloud user" : "Nextcloud-användare",
    "User password" : "Användarlösenord",
    "Talk conversation" : "Talk-konversation",
    "Skip TLS verification" : "Skippa TLS-verifiering",
    "Matrix server URL" : "Matrix server-URL",
    "User" : "Användare",
    "Matrix channel" : "Matrix-kanal",
    "Mattermost server URL" : "Mattermost server-URL",
    "Mattermost user" : "Mattermost-användare",
    "Team name" : "Namn på team",
    "Channel name" : "Kanalnamn",
    "Rocket.Chat server URL" : "Rocket.Chat server-URL",
    "User name or email address" : "Användarnamn eller e-postadress",
    "Rocket.Chat channel" : "Rocket.Chatt-kanal",
    "Zulip server URL" : "Zulip server-URL",
    "Bot user name" : "Bott användarnamn",
    "Bot API key" : "Bott API-nyckel",
    "Zulip channel" : "Zulip kanal",
    "API token" : "API-token",
    "Slack channel" : "Slack-kanal",
    "Server ID or name" : "Server-ID eller namn",
    "Channel ID (prefixed with \"ID:\") or name" : "Kanal-ID (med prefixet \"ID:\") eller namn",
    "Channel" : "Kanal",
    "Login" : "Logga in",
    "Chat ID" : "Chatt-ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC server-URL (t.ex. chat.freenode.net:6667)",
    "Nickname" : "Smeknamn",
    "Connection password" : "Anslutningslösenord",
    "IRC channel" : "IRC-kanal",
    "Channel password" : "Kanallösenord",
    "NickServ nickname" : "NickServ smeknamn",
    "NickServ password" : "NickServ lösenord",
    "Use TLS" : "Använd TLS",
    "Use SASL" : "Använd SASL",
    "Tenant ID" : "Tenant-ID",
    "Client ID" : "Klient-ID",
    "Team ID" : "Team-ID",
    "Thread ID" : "Tråd-ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber server-URL",
    "MUC server URL" : "MUC server-URL",
    "Jabber ID" : "Jabber-id",
    "Pinned messages" : "Fästa meddelanden",
    "Media" : "Media",
    "Polls" : "Omröstningar",
    "Deck cards" : "Deck-kort",
    "Voice messages" : "Röstmeddelanden",
    "Locations" : "Platser",
    "Call recordings" : "Samtalsinspelningar",
    "Audio" : "Ljud",
    "Show all pinned messages" : "Visa alla fästa meddelanden",
    "Show all media" : "Visa alla media",
    "Show all files" : "Visa alla filer",
    "Show all polls" : "Visa alla omröstningar",
    "Show all deck cards" : "Visa alla Deck-kort",
    "Show all voice messages" : "Visa alla röstmeddelanden",
    "Show all locations" : "Visa alla platser",
    "Show all call recordings" : "Visa alla samtalsinspelningar",
    "Show all audio" : "Visa allt ljud",
    "Show all other" : "Visa alla andra",
    "Follow conversation settings" : "Följ konversationsinställningar",
    "Group" : "Grupp",
    "Team" : "Team",
    "You reconnected to the call" : "Du återanslöt till samtalet",
    "{actor} reconnected to the call" : "{actor} återanslöt till samtalet",
    "You added {user0} and {user1}" : "Du lade till {user0} och {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Du lade till {user0}, {user1} och %n mer deltagare","Du lade till {user0}, {user1} och %n fler deltagare"],
    "An administrator added you and {user0}" : "En administratör lade till dig och {user0}",
    "{actor} added you and {user0}" : "{actor} lade till dig och {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["En administratör lade till dig, {user0} och %n mer deltagare","En administratör lade till dig, {user0} och %n fler deltagare"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} lade till dig, {user0} och %n mer deltagare","{actor} lade till dig, {user0} och %n fler deltagare"],
    "An administrator added {user0} and {user1}" : "En administratör lade till {user0} och {user1}",
    "{actor} added {user0} and {user1}" : "{actor} lade till {user0} och {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["En administratör lade till {user0}, {user1} och %n mer deltagare","En administratör lade till {user0}, {user1} och %n fler deltagare"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} lade till {user0}, {user1} och %n mer deltagare","{actor} lade till {user0}, {user1} och %n fler deltagare"],
    "You removed {user0} and {user1}" : "Du tog bort {user0} och {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Du tog bort {user0}, {user1} och %n mer deltagare","Du tog bort {user0}, {user1} och %n fler deltagare"],
    "An administrator removed you and {user0}" : "En administratör tog bort dig och {user0}",
    "{actor} removed you and {user0}" : "{actor} tog bort dig och {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["En administratör tog bort dig, {user0} och %n mer deltagare","En administratör tog bort dig, {user0} och %n fler deltagare"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} tog bort dig, {user0} och %n mer deltagare","{actor} tog bort dig, {user0} och %n fler deltagare"],
    "An administrator removed {user0} and {user1}" : "En administratör tog bort {user0} och {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} tog bort {user0} och {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["En administratör tog bort {user0}, {user1} och %n mer deltagare","En administratör tog bort {user0}, {user1} och %n fler deltagare"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} tog bort {user0}, {user1} och %n mer deltagare","{actor} tog bort {user0}, {user1} och %n fler deltagare"],
    "You and {user0} joined the call" : "Du och {user0} gick med i samtalet",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Du, {user0} och %n mer deltagare gick med i samtalet","Du, {user0} och %n fler deltagare gick med i samtalet"],
    "{user0} and {user1} joined the call" : "{user0} och {user1} gick med i samtalet",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} och %n mer deltagare gick med i samtalet","{user0}, {user1} och %n fler deltagare gick med i samtalet"],
    "You and {user0} left the call" : "Du och {user0} lämnade samtalet",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Du, {user0} och %n mer deltagare lämnade samtalet","Du, {user0} och %n fler deltagare lämnade samtalet"],
    "{user0} and {user1} left the call" : "{user0} och {user1} lämnade samtalet",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} och %n mer deltagare lämnade samtalet","{user0}, {user1} och %n fler deltagare lämnade samtalet"],
    "You promoted {user0} and {user1} to moderators" : "Du befordrade {user0} och {user1} till moderatorer",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Du befordrade {user0}, {user1} och %n mer deltagare till moderatorer","Du befordrade {user0}, {user1} och %n fler deltagare till moderatorer"],
    "An administrator promoted you and {user0} to moderators" : "En administratör befordrade dig och {user0} till moderatorer",
    "{actor} promoted you and {user0} to moderators" : "{actor} befordrade dig och {user0} till moderatorer",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["En administratör befordrade dig, {user0} och %n mer deltagare till moderatorer","En administratör befordrade dig, {user0} och %n fler deltagare till moderatorer"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} befordrade dig, {user0} och %n mer deltagare till moderatorer","{actor} befordrade dig, {user0} och %n fler deltagare till moderatorer"],
    "An administrator promoted {user0} and {user1} to moderators" : "En administratör befordrade {user0} och {user1} till moderatorer",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} befordrade {user0} och {user1} till moderatorer",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["En administratör befordrade {user0}, {user1} och %n mer deltagare till moderatorer","En administratör befordrade {user0}, {user1} och %n fler deltagare till moderatorer"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} befordrade {user0}, {user1} och %n mer deltagare till moderatorer","{actor} befordrade {user0}, {user1} och %n fler deltagare till moderatorer"],
    "You demoted {user0} and {user1} from moderators" : "Du degraderade {user0} och {user1} från moderatorer",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Du degraderade {user0}, {user1} och %n mer deltagare från moderatorer","Du degraderade {user0}, {user1} och %n fler deltagare från moderatorer"],
    "An administrator demoted you and {user0} from moderators" : "En administratör degraderade dig och {user0} från moderatorer",
    "{actor} demoted you and {user0} from moderators" : "{actor} degraderade dig och {user0} från moderatorer",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["En administratör degraderade dig, {user0} och %n mer deltagare från moderatorer","En administratör degraderade dig, {user0} och %n fler deltagare från moderatorer"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} degraderade dig, {user0} och %n mer deltagare från moderatorer","{actor} degraderade dig, {user0} och %n fler deltagare från moderatorer"],
    "An administrator demoted {user0} and {user1} from moderators" : "En administratör degraderade {user0} och {user1} från moderatorer",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} degraderade {user0} och {user1} från moderatorer",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["En administratör degraderade {user0}, {user1} och %n mer deltagare från moderatorer","En administratör degraderade {user0}, {user1} och %n fler deltagare från moderatorer"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} degraderade {user0}, {user1} och %n till deltagare från moderatorer","{actor} degraderade {user0}, {user1} och %n fler deltagare från moderatorer"],
    "You:" : "Du:",
    "You: {lastMessage}" : "Du: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Servern har uppdaterats.",
    "(edited by you)" : "(redigerad av dig)",
    "(edited by a deleted user)" : "(redigerad av en borttagen användare)",
    "(edited by {moderator})" : "(redigerad av {moderator})",
    "The recording failed. Please contact your administrator." : "Samtalsinspelning misslyckades. Kontakta din administratör.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Du försöker gå med i en konversation medan du har en aktiv session i ett annat fönster eller en annan enhet. Detta stöds för närvarande inte av Nextcloud Talk. Vad vill du göra?",
    "Leave this page" : "Lämna denna sida",
    "Join here" : "Gå med här",
    "Deck card has been posted to {conversation}" : "Deck-kort har skickats till {conversation}",
    "An error occurred while posting deck card to conversation" : "Ett fel uppstod när Deck-kortet skulle publiceras i konversationen",
    "Post to a conversation" : "Publicera i en konversation",
    "Post to conversation" : "Skicka till konversation",
    "Location has been posted to {conversation}" : "Plats har skickats till {conversation}",
    "An error occurred while posting location to conversation" : "Ett fel uppstod när platsen skulle publiceras i konversationen",
    "Share to a conversation" : "Dela till en konversation",
    "Share to conversation" : "Dela till konversation",
    "In conversation" : "I konversation",
    "Search in conversation: {conversation}" : "Sök i konversation: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Dina förfrågningar fördröjs för tillfället på grund av brute force-skydd",
    "Error while clearing conversation history" : "Kunde inte rensa konversationshistorik",
    "Error occurred while allowing guests" : "Ett fel uppstod när gäster skulle tillåtas",
    "Error occurred while disallowing guests" : "Ett fel uppstod vid avvisning av gäster",
    "Error occurred when restricting the conversation to moderator" : "Ett fel uppstod när konversationen begränsades till moderator",
    "Error occurred when opening the conversation to everyone" : "Ett fel uppstod när konversationen öppnades för alla",
    "Conversation password has been saved" : "Lösenordet för konversationen har sparats",
    "Conversation password has been removed" : "Lösenordet för konversationen har tagits bort",
    "Error occurred while saving conversation password" : "Ett fel uppstod när lösenordet för konversationen skulle sparas",
    "Call recording is starting." : "Samtalsinspelning startar.",
    "Call recording stopped while starting." : "Samtalsinspelning stoppades vid start.",
    "Call recording stopped. You will be notified once the recording is available." : "Samtalsinspelning stoppad. Du kommer att meddelas när inspelningen är tillgänglig.",
    "Conversation picture set" : "Konversationsbild inställd",
    "Conversation picture deleted" : "Konversationsbild raderad",
    "Could not delete the conversation picture" : "Kunde inte ta bort konversationsbilden",
    "Could not remove the automatic expiration" : "Kunde inte ta bort den automatiska utgången",
    "Could not post message: {errorMessage}" : "Kunde inte skicka meddelandet: {errorMessage}",
    "Participant is banned successfully" : "Deltagaren har blockerats",
    "Error while banning the participant" : "Fel vid blockering av deltagaren",
    "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
    "Could not send invitation to {actorId}" : "Kunde inte skicka inbjudan till {actorId}",
    "Invitations sent" : "Inbjudningar skickade",
    "Error occurred when sending invitations" : "Ett fel uppstod när inbjudningar skickades",
    "Failed to join the conversation." : "Det gick inte att gå med i konversationen.",
    "An error occurred while creating breakout rooms" : "Ett fel uppstod när grupprum skapades",
    "An error occurred while re-ordering the attendees" : "Ett fel uppstod när deltagarna skulle ordnas om",
    "An error occurred while deleting breakout rooms" : "Ett fel uppstod när grupprum skulle raderas",
    "An error occurred while starting breakout rooms" : "Ett fel uppstod när grupprum skulle startas",
    "An error occurred while stopping breakout rooms" : "Ett fel uppstod när grupprum skulle stoppas",
    "An error occurred while sending a message to the breakout rooms" : "Ett fel uppstod när ett meddelande skickades till grupprummen",
    "An error occurred while requesting assistance" : "Ett fel uppstod vid begäran om hjälp",
    "An error occurred while resetting the request for assistance" : "Ett fel uppstod när begäran om hjälp återställdes",
    "An error occurred while joining breakout room" : "Ett fel uppstod när du gick med i grupprummet",
    "Failed to rename the thread" : "Kunde inte byta namn på tråd",
    "Error renaming tag" : "Kunde inte byta namn på tagg",
    "Error deleting tag" : "Kunde inte ta bort tagg",
    "Error reordering tags" : "Kunde inte sortera om taggar",
    "Error fetching upcoming events" : "Kunde inte hämta kommande händelser",
    "Error fetching upcoming reminders" : "Kunde inte hämta kommande påminnelser",
    "An error occurred while accepting an invitation" : "Ett fel uppstod när en inbjudan skulle accepteras",
    "An error occurred while rejecting an invitation" : "Ett fel uppstod när en inbjudan skulle avvisas",
    "{guest} (guest)" : "{guest} (gäst)",
    "Poll draft has been saved" : "Omröstningsutkast sparat",
    "An error occurred while saving the draft" : "Ett fel uppstod när utkastet skulle sparas",
    "An error occurred while submitting your vote" : "Ett fel uppstod när din röst skulle skickas",
    "An error occurred while ending the poll" : "Ett fel uppstod när omröstningen stoppades",
    "An error occurred while deleting the poll draft" : "Ett fel uppstod när utkastet till omröstningen skulle raderas",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Omröstningen \"{name}\" skapades av {user}. Klicka för att rösta",
    "Failed to add reaction" : "Kunde inte lägga till reaktion",
    "Failed to remove reaction" : "Kunde inte ta bort reaktionen",
    "The server is in maintenance mode." : "Servern är i underhållsläge.",
    "Federated server was updated." : "Den federerade servern har uppdaterats.",
    "Error while uploading file \"{fileName}\"" : "Fel vid uppladdning av fil \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Inte tillräckligt med ledigt utrymme för att ladda upp filen \"{fileName}\"",
    "You are not allowed to share files" : "Du tillåẗs inte dela filer",
    "Error while sharing file" : "Fel vid delning av fil",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Webbläsaren du använder stöds inte fullt ut av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n timme","%n timmar"],
    "_%n day_::_%n days_" : ["%n dag","%n dagar"],
    "_%n week_::_%n weeks_" : ["%n vecka","%n veckor"],
    "_In %n hour_::_In %n hours_" : ["Om %n timme","Om %n timmar"],
    "_%n minute _::_%n minutes_" : ["%n minut","%n minuter"],
    "In {hours} and {minutes}" : "Om {hours} och {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Om %n minut","Om %n minuter"],
    "Later today – {timeLocale}" : "Senare idag – {timeLocale}",
    "Set time for later today" : "Välj tid senare idag",
    "Tomorrow – {timeLocale}" : "Imorgon – {timeLocale}",
    "Set time for tomorrow" : "Välj tid i morgon",
    "This weekend – {timeLocale}" : "Den här helgen – {timeLocale}",
    "Set time for this weekend" : "Välj tid i helgen",
    "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
    "Set time for next week" : "Välj tid nästa vecka",
    "Message link copied to clipboard" : "Meddelandelänk kopierad till urklipp",
    "Conversation link copied to clipboard" : "Konversationslänk kopierad till urklipp",
    "The link could not be copied" : "Länken kunde inte kopieras",
    "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
    "Sending signaling message has failed" : "Misslyckades skicka signalmeddelande",
    "Lost connection to signaling server. Trying to reconnect." : "Förlorade anslutningen till signalservern. Försöker ansluta igen.",
    "Lost connection to signaling server." : "Anslutningen till signalservern förlorades.",
    "Connecting is taking longer than expected …" : "Anslutningen tar längre tid än förväntat …",
    "Failed to connect. Retrying …" : "Kunde inte ansluta. Försöker igen …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Kunde inte ansluta. Signalservern kan vara felkonfigurerad",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Den konfigurerade signalservern måste uppdateras för att vara kompatibel med den här versionen av Talk. Kontakta din administratör.",
    "Please restart the app." : "Starta om appen.",
    "Please reload the page." : "Uppdatera sidan.",
    "Please try to restart the app." : "Försök att starta om appen.",
    "Please try to reload the page." : "Försök att ladda om sidan.",
    "Do not disturb" : "Stör ej",
    "Away" : "Borta",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Högtalare {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Det gick inte att upprätta en anslutning med minst en deltagare. En TURN-server kan behövas för ditt scenario. Be din administratör att ställa in en med hjälp av {linkstart}den här dokumentationen{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
    "Access to microphone & camera is only possible with HTTPS" : "Åtkomst till mikrofon och kamera är endast möjligt via HTTPS",
    "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
    "Access to microphone & camera was denied" : "Åtkomst till mikrofon och kamera nekades",
    "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
    "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Fel vid åtkomst till mikrofon och kamera",
    "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
    "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
    "Android app" : "Android-app",
    "iOS app" : " iOS-app",
    "__language_name__" : "Svenska",
    "Webhook Demo" : "Webhook-demo",
    "Call summary (%s)" : "Samtalssammanfattning (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Samtalssammanfattningsboten publicerar ett översiktsmeddelande efter samtalet med en lista över alla deltagare och uppgifter",
    "Tasks" : "Uppgifter",
    "Notes" : "Anteckning",
    "Reports" : "Rapporter",
    "Decisions" : "Beslut",
    "Agenda" : "Agenda",
    "Call summary" : "Samtalssammanfattning",
    "Call summary - {title}" : "Samtalssammanfattning - {title}",
    "Talk to %s" : "Chatta med %s",
    "Talk conversation for event" : "Talk-konversation för händelse",
    "Client Push is installed, this improves the performance of desktop clients." : "Klient-Push är installerat, detta förbättrar prestandan för skrivbordsklienter.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} är inte installerat, detta kan leda till prestandaproblem vid användning av skrivbordsklienter.",
    "Next meeting" : "Nästa möte",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Schemalägg ett möte från din kalender. En Talk-konversation måste anges som plats för att visas här",
    "Join conversations from remote Nextcloud servers" : "Gå med i konversationer från fjärranslutna Nextcloud-servrar",
    "Your default media state has been saved" : "Din standard för mediastatus har sparats",
    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
    "Generate summary" : "Skapa en sammanfattning",
    "Open poll • You voted already" : "Öppna omröstning • Du har redan röstat",
    "Open poll • Click to vote" : "Öppna omröstning • Klicka för att rösta",
    "Poll • Ended" : "Omröstning • Avslutad",
    "Talk recording from {time} ({conversation})" : "Talk-inspelning från {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Omröstningsresultat • %n röst","Omröstningsresultat • %n röster"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Öppna omröstning • %n röst","Öppna omröstning • %n röster"],
    "Submit vote" : "Skicka in röst",
    "Your privacy setting has been saved" : "Din integritetsinställning har sparats",
    "Your personal setting has been saved" : "Din personliga inställning har sparats",
    "Failed to save sounds setting" : "Det gick inte att spara ljudinställningen",
    "Sounds setting saved" : "Ljudinställningen sparad",
    "Always shown if recording consent is required" : "Visas alltid om samtycke till inspelning krävs",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk har uppdaterats, du kan inte starta eller gå med i ett samtal.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Du gick med i konversationen i ett annat fönster eller en annan enhet. Detta stöds för närvarande inte av Nextcloud Talk så denna session stängdes.",
    "Nextcloud Talk was updated." : "Nextcloud Talk har uppdaterats.",
    "Nextcloud is in maintenance mode." : "Nextcloud är i underhållsläge.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation har uppdaterats.",
    "Enable live translation" : "Aktivera live-översättning",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["Öppen omröstning • %n röst • Din röst är anonym","Öppen omröstning • %n röster • Din röst är anonym"],
    "Open poll • You voted already • Your vote is anonymous" : "Öppen omröstning • Du har redan röstat • Din röst är anonym",
    "Open poll • Your vote is anonymous" : "Öppen omröstning • Din röst är anonym",
    "I picked list style" : "Jag valde listvy",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hej! Använder du Talk i listvy eller meddelandebubblor?"
},
"nplurals=2; plural=(n != 1);");
